/*
 * Generate a VGA signal using a PIC32 microcontroller.
 *
 * Copyright (C) 2017 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "mips.h"
#include "pic32.h"

#define LINE_LENGTH	160	/* pixels */

#define HFREQ_LIMIT	643	/* 24MHz cycles */
#define HSYNC_START	460	/* 24MHz cycles */
#define HSYNC_LIMIT	64	/* 24MHz cycles */
#define HSYNC_END	(HSYNC_START + HSYNC_LIMIT)

#define VISIBLE_START	70	/* horizontal lines, back porch end */
#define VFP_START	592	/* horizontal lines, front porch start */
#define VSYNC_START	620	/* horizontal lines, front porch end */
#define VSYNC_END	622	/* horizontal lines, back porch start */

#define SCREEN_SIZE	(40 * 1024)

/* Disable JTAG functionality on pins. */

.section .devcfg0, "a"
.word 0xfffffffb	/* DEVCFG0<2> = JTAGEN = 0 */

/*
Set the oscillator to be the FRC oscillator with PLL, with peripheral clock
divided by 2, and FRCDIV+PLL selected.

The watchdog timer (FWDTEN) is also disabled.

The secondary oscillator pin (FSOSCEN) is disabled to avoid pin conflicts with
RPB4.
*/

.section .devcfg1, "a"
.word 0xff7fdfd9	/* DEVCFG1<23> = FWDTEN = 0; DEVCFG1<13:12> = FPBDIV<1:0> = 1;
			DEVCFG1<5> = FSOSCEN = 0; DEVCFG1<2:0> = FNOSC<2:0> = 001 */

/*
Set the FRC oscillator PLL function with an input division of 4, an output
division of 2, a multiplication of 24, yielding a multiplication of 3.

The FRC is apparently at 16MHz and this produces a system clock of 48MHz.
*/

.section .devcfg2, "a"
.word 0xfff9fffb	/* DEVCFG2<18:16> = FPLLODIV<2:0> = 001;
			DEVCFG2<6:4> = FPLLMUL<2:0> = 111;
			DEVCFG2<2:0> = FPLLIDIV<2:0> = 011 */

.text
.globl _start

_start:
	/*
	Configure RAM.
	See: http://microchipdeveloper.com/32bit:mx-arch-exceptions-processor-initialization
	*/

	la $v0, BMXCON
	lw $v1, 0($v0)
	li $t8, ~(1 << 6)	/* BMXCON<6> = BMXWSDRM = 0 */
	and $v1, $v1, $t8
	li $t8, ~0b111		/* BMXCON<2:0> = BMXARB<2:0> = 0 */
	ori $t8, $t8, 0b010	/* BMXCON<2:0> = BMXARB<2:0> = 2 */
	and $v1, $v1, $t8
	sw $v1, 0($v0)

	/* Enable caching. */

	mfc0 $v1, CP0_CONFIG
	li $t8, ~CONFIG_K0
	and $v1, $v1, $t8
	ori $v1, $v1, CONFIG_K0_CACHABLE_NONCOHERENT
	mtc0 $v1, CP0_CONFIG
	nop

	/* Get the RAM size. */

	la $v0, BMXDRMSZ
	lw $t0, 0($v0)

	/* Initialise the stack pointer. */

	li $v1, KSEG0_BASE
	addu $sp, $t0, $v1	/* sp = KSEG0_BASE + RAM size */

	/* Initialise the globals pointer. */

	lui $gp, %hi(_GLOBAL_OFFSET_TABLE_)
	ori $gp, $gp, %lo(_GLOBAL_OFFSET_TABLE_)

	/* Set pins for output. */

	jal init_pins
	nop

	la $t0, PORTA
	li $t1, (1 << 3)	/* PORTA<3> = RA3 */
	sw $t1, CLR($t0)

	jal init_oc_pins
	nop

	/* Initialise the status register. */

	jal init_interrupts
	nop

	/* Initialise framebuffer. */

	jal init_framebuffer
	nop

	sync

	/* Initialise timer. */

	jal init_timer2
	nop

	/* Initialise DMA. */

	jal init_dma
	nop

	/* Initialise OC1 and OC2. */

	jal init_oc
	nop

	/* Enable interrupts and loop. */

	jal enable_interrupts
	nop

	jal handle_error_level
	nop

	/* Main program. */

	li $a1, 5000000		/* counter = 5000000 */

	/* Initialise the display state. */

	li $s0, 0		/* line counter */
	la $s1, vbp_active	/* current event */
	move $s2, $zero		/* line address */
	move $s3, $zero		/* screen address */

	/* Monitoring loop. */
loop:
	addiu $a1, $a1, -1	/* counter -= 1 */
	bnez $a1, loop		/* until counter == 0 */
	nop

	li $a1, 5000000		/* counter = 5000000 */

	la $t0, PORTA
	li $t1, (1 << 3)	/* PORTA<3> = RA3 */
	sw $t1, INV($t0)

_next:
	j loop
	nop



init_pins:
	/* DEVCFG0<2> needs setting to 0 before the program is run. */

	la $v0, CFGCON
	li $v1, (1 << 3)	/* CFGCON<3> = JTAGEN = 0 */
	sw $v1, CLR($v0)

init_outputs:
	/* Remove analogue features from pins. */

	la $v0, ANSELA
	sw $zero, 0($v0)	/* ANSELA = 0 */
	la $v0, ANSELB
	sw $zero, 0($v0)	/* ANSELB = 0 */

	la $v0, TRISA
	sw $zero, 0($v0)
	la $v0, TRISB
	sw $zero, 0($v0)

	la $v0, PORTA
	sw $zero, 0($v0)
	la $v0, PORTB
	sw $zero, 0($v0)

	jr $ra
	nop



/* Initialisation routines. */

init_timer2:

	/* Initialise Timer2 interrupt. */

	la $v0, T2CON
	sw $zero, 0($v0)	/* T2CON = 0 */
	nop

	la $v0, TMR2
	sw $zero, 0($v0)	/* TMR2 = 0 */

	la $v0, PR2
	li $v1, HFREQ_LIMIT
	sw $v1, 0($v0)		/* PR2 = HFREQ_LIMIT */

	/* Initialise Timer2 interrupt. */

	la $v0, IFS0
	li $v1, (1 << 9)
	sw $v1, CLR($v0)	/* T2IF = 0 */

	la $v0, IPC2
	li $v1, 0b11111
	sw $v1, CLR($v0)	/* T2IP, T2IS = 0 */

	la $v0, IPC2
	li $v1, 0b11111
	sw $v1, SET($v0)	/* T2IP = 7; T2IS = 3 */

	la $v0, IEC0
	li $v1, (1 << 9)
	sw $v1, SET($v0)	/* T2IE = 1 */

	/* Start timer. */

	la $v0, T2CON
	li $v1, (1 << 15)
	sw $v1, SET($v0)	/* ON = 1 */

	jr $ra
	nop



/*
Output compare initialisation.

Timer2 will be used to trigger two events using OC1: one initiating the hsync
pulse, and one terminating the pulse. The pulse should appear after the line
data has been transferred using DMA, but this is achieved by just choosing
suitable start and end values.

Using OC2, Timer 2 triggers a level shifting event and OC2 is reconfigured to
reverse the level at a later point.
*/

init_oc:
	/* Disable OC1 interrupts. */

	la $v0, IEC0
	li $v1, (1 << 7)	/* IEC0<7> = OC1IE = 0 */
	sw $v1, CLR($v0)

	la $v0, IFS0
	li $v1, (1 << 7)	/* IFS0<7> = OC1IF = 0 */
	sw $v1, CLR($v0)

	/* Initialise OC1. */

	la $v0, OC1CON
	li $v1, 0b101		/* OC1CON<2:0> = OCM<2:0> = 101 (dual compare, continuous pulse) */
	sw $v1, 0($v0)

	/* Pulse start and end. */

	la $v0, OC1R
	li $v1, HSYNC_END	/* HSYNC_START for positive polarity */
	sw $v1, 0($v0)

	la $v0, OC1RS
	li $v1, HSYNC_START	/* HSYNC_END for positive polarity */
	sw $v1, 0($v0)

	/* OC1 is enabled. */

	la $v0, OC1CON
	li $v1, (1 << 15)
	sw $v1, SET($v0)

	/* Disable OC2 interrupts. */

	la $v0, IEC0
	li $v1, (1 << 12)	/* IEC0<12> = OC2IE = 0 */
	sw $v1, CLR($v0)

	la $v0, IFS0
	li $v1, (1 << 12)	/* IFS0<12> = OC2IF = 0 */
	sw $v1, CLR($v0)

	/* Initialise OC2. */

	la $v0, OC2CON
	li $v1, 0b010		/* OC2CON<2:0> = OCM<2:0> = 010 (single compare, output driven low) */
	sw $v1, 0($v0)

	/* Set pulse position. */

	la $v0, OC2R
	sw $zero, 0($v0)

	/* Enable OC2 later. */

	jr $ra
	nop


init_oc_pins:
	/* Unlock the configuration register bits. */

	la $v0, SYSKEY
	sw $zero, 0($v0)
	li $v1, 0xAA996655
	sw $v1, 0($v0)
	li $v1, 0x556699AA
	sw $v1, 0($v0)

	la $v0, CFGCON
	lw $t8, 0($v0)
	li $v1, (1 << 13)	/* IOLOCK = 0 */
	sw $v1, CLR($v0)

	/* Map OC1 to RPA0. */

	la $v0, RPA0R
	li $v1, 0b0101		/* RPA0R<3:0> = 0101 (OC1) */
	sw $v1, 0($v0)

	/* Map OC2 to RPA1. */

	la $v0, RPA1R
	li $v1, 0b0101		/* RPA1R<3:0> = 0101 (OC2) */
	sw $v1, 0($v0)

	la $v0, CFGCON
	sw $t8, 0($v0)

	/* Lock the oscillator control register again. */

	la $v0, SYSKEY
	li $v1, 0x33333333
	sw $v1, 0($v0)

	jr $ra
	nop



/*
Direct Memory Access initialisation.

Write 160 pixels to PORTB for the line data. This is initiated by a timer
interrupt. Upon completion of the transfer, a DMA interrupt initiates the
address update routine, changing the source address of the DMA channel.
*/

init_dma:
	/* Disable DMA interrupts. */

	la $v0, IEC1
	li $v1, (3 << 28)	/* IEC1<29:28> = DMA1IE, DMA0IE = 0 */
	sw $v1, CLR($v0)

	/* Clear DMA interrupt flags. */

	la $v0, IFS1
	li $v1, (3 << 28)	/* IFS1<29:28> = DMA1IF, DMA0IF = 0 */
	sw $v1, CLR($v0)

	/* Enable DMA. */

	la $v0, DMACON
	li $v1, (1 << 15)
	sw $v1, SET($v0)

	/*
	Initialise a line channel.
	The line channel will be channel 0 (x = 0).

	Specify a priority of 3:
	DCHxCON<1:0> = CHPRI<1:0> = 3

	Auto-enable the channel:
	DCHxCON<4> = CHAEN = 1
	*/

	la $v0, DCH0CON
	li $v1, 0b10011
	sw $v1, 0($v0)

	/*
	Initialise a level reset channel.
	The reset channel will be channel 1 (x = 1).

	Specify a priority of 3:
	DCHxCON<1:0> = CHPRI<1:0> = 3

	Chain the channel to channel 0:
	DCHxCON<5> = CHCHN = 1

	Allow the channel to receive events when disabled:
	DCHxCON<6> = CHAED = 1
	*/

	la $v0, DCH1CON
	li $v1, 0b1100011
	sw $v1, 0($v0)

	/*
	Initiate channel transfers when the initiating interrupt condition
	occurs:
	DCHxECON<15:8> = CHSIRQ<7:0> = timer 2 interrupt
	DCHxECON<4> = SIRQEN = 1

	For now, however, prevent initiation by not setting SIRQEN.
	*/

	la $v0, DCH0ECON
	li $v1, (9 << 8)
	sw $v1, 0($v0)

	/*
	Initiate reset channel transfer when channel 0 is finished:
	DCHxECON<15:8> = CHSIRQ<7:0> = channel 0 interrupt
	DCHxECON<4> = SIRQEN = 1
	*/

	la $v0, DCH1ECON
	li $v1, (60 << 8) | (1 << 4)
	sw $v1, 0($v0)

	/*
	The line channel has a cell size of the number bytes in a line:
	DCHxCSIZ<15:0> = CHCSIZ<15:0> = LINE_LENGTH
	*/

	la $v0, DCH0CSIZ
	li $v1, LINE_LENGTH
	sw $v1, 0($v0)

	/*
	The reset channel has a cell size of a single zero byte:
	DCHxCSIZ<15:0> = CHCSIZ<15:0> = LINE_LENGTH
	*/

	la $v0, DCH1CSIZ
	li $v1, 1
	sw $v1, 0($v0)

	/*
	The source has a size identical to the cell size:
	DCHxSSIZ<15:0> = CHSSIZ<15:0> = LINE_LENGTH
	*/

	la $v0, DCH0SSIZ
	li $v1, LINE_LENGTH
	sw $v1, 0($v0)

	la $v0, DCH1SSIZ
	li $v1, 1
	sw $v1, 0($v0)

	/*
	The source address is the physical address of the line data:
	DCHxSSA = physical(line data address)
	*/

	la $v0, DCH0SSA
	sw $zero, 0($v0)

	/*
	For the reset channel, a single byte of zero is transferred:
	DCHxSSA = physical(zero data address)
	*/

	la $v0, DCH1SSA
	la $v1, zerodata
	li $t8, KSEG0_BASE
	subu $v1, $v1, $t8
	sw $v1, 0($v0)

	/*
	The destination has a size of 1 byte:
	DCHxDSIZ<15:0> = CHDSIZ<15:0> = 1
	*/

	la $v0, DCH0DSIZ
	li $v1, 1
	sw $v1, 0($v0)

	la $v0, DCH1DSIZ
	sw $v1, 0($v0)

	/*
	The destination address is the physical address of PORTB:
	DCHxDSA = physical(PORTB)
	*/

	la $v0, DCH0DSA
	li $v1, PORTB
	li $t8, KSEG1_BASE
	subu $v1, $v1, $t8
	sw $v1, 0($v0)

	la $v0, DCH1DSA
	sw $v1, 0($v0)

	/*
	Use the block transfer completion interrupt to indicate when the source
	address can be updated.
	*/

	la $v0, DCH0INT
	li $v1, (1 << 19)	/* CHBCIE = 1 */
	sw $v1, 0($v0)

	/* Enable interrupt for address updating. */

	la $v0, IPC10
	li $v1, 0b11111		/* DMA0IP, DMA0IS = 0 */
	sw $v1, CLR($v0)

	la $v0, IPC10
	li $v1, 0b11111		/* DMA0IP = 7, DMA0IS = 3 */
	sw $v1, SET($v0)

	la $v0, IEC1
	li $v1, (1 << 28)	/* IEC1<28> = DMA0IE = 1 */
	sw $v1, SET($v0)

	/* Enable line channel. */

	la $v0, DCH0CON
	li $v1, 0b10000000
	sw $v1, SET($v0)

	jr $ra
	nop

zerodata:
.word 0



/* Framebuffer initialisation. */

init_framebuffer:
	li $v0, KSEG1_BASE
	la $v1, screendata
	li $t8, SCREEN_SIZE

_init_fb_loop:
	lw $t9, 0($v1)
	sw $t9, 0($v0)
	addiu $v0, $v0, 4
	addiu $v1, $v1, 4
	addiu $t8, $t8, -4
	bnez $t8, _init_fb_loop
	nop

	jr $ra
	nop



/* Utilities. */

handle_error_level:
	mfc0 $t3, CP0_STATUS
	li $t4, ~(STATUS_ERL | STATUS_EXL)
	and $t3, $t3, $t4
	mtc0 $t3, CP0_STATUS
	jr $ra
	nop

enable_interrupts:
	mfc0 $t3, CP0_STATUS
	li $t4, ~STATUS_IRQ	/* Clear interrupt priority bits. */
	and $t3, $t3, $t4
	li $t4, ~STATUS_BEV	/* CP0_STATUS &= ~STATUS_BEV (use non-bootloader vectors) */
	and $t3, $t3, $t4
	ori $t3, $t3, STATUS_IE
	mtc0 $t3, CP0_STATUS
	jr $ra
	nop

init_interrupts:
	mfc0 $t3, CP0_DEBUG
	li $t4, ~DEBUG_DM
	and $t3, $t3, $t4
	mtc0 $t3, CP0_DEBUG

	mfc0 $t3, CP0_STATUS
	li $t4, STATUS_BEV	/* BEV = 1 or EBASE cannot be set */
	or $t3, $t3, $t4
	mtc0 $t3, CP0_STATUS

	la $t3, exception_handler
	mtc0 $t3, CP0_EBASE	/* EBASE = exception_handler */

	li $t3, 0x20		/* Must be non-zero or the CPU gets upset */
	mtc0 $t3, CP0_INTCTL

	li $t3, CAUSE_IV	/* IV = 1 (use EBASE+0x200 for interrupts) */
	mtc0 $t3, CP0_CAUSE

	jr $ra
	nop



/* Exception servicing. */

.section .flash, "a"

exception_handler:
	li $t8, 2500000
exc_loop:
	addiu $t8, $t8, -1
	bnez $t8, exc_loop
	nop
	la $v0, PORTA
	li $v1, (1 << 2)	/* PORTA<2> = RA2 */
	sw $v1, INV($v0)
	j exception_handler
	nop



/* Interrupt servicing. */

.org 0x200

interrupt_handler:

	/* Check for a timer interrupt condition. */

	la $v0, IFS0
	lw $v1, 0($v0)
	andi $v1, $v1, (1 << 9)	/* T2IF */
	beqz $v1, irq_dma
	nop

	/* Increment the line counter. */

	addiu $s0, $s0, 1

	/* Jump to the event handler. */

	jalr $s1
	nop

irq_clear_timer:

	/* Clear the timer interrupt condition. */

	la $v0, IFS0
	li $v1, (1 << 9)	/* IFS0<9> = T2IF = 0 */
	sw $v1, CLR($v0)

irq_dma:

	/* Check for a DMA interrupt condition. */

	la $v0, IFS1
	lw $v1, 0($v0)
	li $t8, (1 << 28)	/* DMA0IF */
	and $v1, $v1, $t8
	beqz $v1, irq_exit
	nop

	/* Test the block transfer completion interrupt flag. */

	la $v0, DCH0INT
	lw $v1, 0($v0)
	andi $v1, $v1, (1 << 3)	/* CHBCIF */
	beqz $v1, irq_clear_dma
	nop

	/* Clear the block transfer completion interrupt flag. */

	li $v1, (1 << 3)	/* CHBCIF = 0 */
	sw $v1, CLR($v0)

	/*
	Update the line data address if the line counter (referring to the
	next line) is even.
	*/

	andi $t8, $s0, 1
	bnez $t8, irq_clear_dma
	nop

	/* Reference the next line and update the DMA source address. */

	addiu $s2, $s2, LINE_LENGTH

	/* Test for wraparound. */

	li $t8, SCREEN_SIZE
	sltu $t8, $s2, $t8
	bnez $t8, irq_dma_update
	nop

	/* Reset the source address. */

	move $s2, $zero

irq_dma_update:

	la $v0, DCH0SSA
	sw $s2, 0($v0)

irq_clear_dma:

	/* Clear the DMA interrupt condition. */

	la $v0, IFS1
	li $v1, (1 << 28)	/* IFS1<28> = DMA0IF = 0 */
	sw $v1, CLR($v0)

irq_exit:
	eret
	nop



/* Event routines. */

/* The vertical back porch. */

vbp_active:
	/* Test for visible region. */

	sltiu $v0, $s0, VISIBLE_START
	bnez $v0, _vbp_active_ret
	nop

	/* Start the visible region. */

	la $s1, visible_active

	/* Reset the line address. */

	move $s2, $s3

	/* Enable the line channel. */

	la $v0, DCH0ECON
	li $v1, (1 << 4)
	sw $v1, SET($v0)

_vbp_active_ret:
	jr $ra
	nop



/* The visible region. */

visible_active:
	/* Test for front porch. */

	sltiu $v0, $s0, VFP_START
	bnez $v0, _visible_active_ret
	nop

	/* Start the front porch region. */

	la $s1, vfp_active

	/* Disable the line channel. */

	la $v0, DCH0ECON
	li $v1, (1 << 4)
	sw $v1, CLR($v0)

_visible_active_ret:
	jr $ra
	nop



/* Within the vertical front porch. */

vfp_active:
	/* Test for vsync. */

	sltiu $v0, $s0, VSYNC_START
	bnez $v0, _vfp_active_ret
	nop

	/* Start the vsync. */

	la $s1, vsync_active

	/* Bring vsync low when the next line starts. */

	la $v0, OC2CON
	li $v1, 0b010 | (1 << 15)	/* OC2CON<2:0> = OCM<2:0> = 010 (single compare, output driven low) */
	sw $v1, 0($v0)

_vfp_active_ret:
	jr $ra
	nop



/* The vsync period. */

vsync_active:
	/* Test for front porch. */

	sltiu $v0, $s0, VSYNC_END
	bnez $v0, _vsync_active_ret
	nop

	/* Start the back porch. */

	move $s0, $zero
	la $s1, vbp_active

	/* Bring vsync high when the next line starts. */

	la $v0, OC2CON
	li $v1, 0b001 | (1 << 15)	/* OC2CON<2:0> = OCM<2:0> = 001 (single compare, output driven high) */
	sw $v1, 0($v0)

_vsync_active_ret:
	jr $ra
	nop



screendata:
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333337
.word 0x37373737
.word 0x37973737
.word 0x37373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37373397
.word 0x97373737
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979737
.word 0x37979797
.word 0x37333797
.word 0x97379737
.word 0x33333797
.word 0x97973733
.word 0x97979797
.word 0x37979797
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37979737
.word 0x37379797
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x32333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x37333337
.word 0x97379797
.word 0x37373737
.word 0x37973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37379797
.word 0x37333737
.word 0x97973797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979737
.word 0x97979797
.word 0x37373797
.word 0x97979797
.word 0x37373797
.word 0x97373733
.word 0x97979797
.word 0x97979797
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x33379737
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x32333333
.word 0x33333333
.word 0x32323232
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373333
.word 0x97979733
.word 0x37379737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37979797
.word 0x33373737
.word 0x97379797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97379737
.word 0x97979797
.word 0x97979797
.word 0x97379797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37373797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x32323332
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333733
.word 0x37373737
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x33373797
.word 0x33339737
.word 0x37373333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x32333233
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x37373737
.word 0x97379737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37979797
.word 0x97973797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37379797
.word 0x97979737
.word 0x37379797
.word 0x97973797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37979737
.word 0x37373737
.word 0x33973737
.word 0x33373797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x32323333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373737
.word 0x37379797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97373797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97379797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37979797
.word 0x37379737
.word 0x37373737
.word 0x97373737
.word 0x97979797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33323233
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373733
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97973797
.word 0x97373737
.word 0x37379733
.word 0x37979797
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x37373733
.word 0x97379797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37379797
.word 0x37333737
.word 0x37333737
.word 0x97979737
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x37973737
.word 0x37973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37333737
.word 0x33379797
.word 0x97973733
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x37373733
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979b97
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37373337
.word 0x97979797
.word 0x97373797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x97373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979b97
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97973337
.word 0x33373797
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373337
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b97979b
.word 0x9797979b
.word 0x97979797
.word 0x9b97979b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x979b9797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b97
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97973797
.word 0x33333797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x97373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b979b
.word 0x9b9b979b
.word 0x9b9b9b97
.word 0x9b979b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b97
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373737
.word 0x97373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9797979b
.word 0x9b9b9b9b
.word 0x979b9b9b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x33373337
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b979b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x979b9b9b
.word 0x97979797
.word 0x97979797
.word 0x37379797
.word 0x33373397
.word 0x33333733
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x37333733
.word 0x97379737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x979b9797
.word 0x97979797
.word 0x97979b97
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b97
.word 0x9b9b979b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x97979b9b
.word 0x97979797
.word 0x97979797
.word 0x37373797
.word 0x37379797
.word 0x33333797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333733
.word 0x33333333
.word 0x33333333
.word 0x37373733
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9bbbbbbb
.word 0x9b9b9bbb
.word 0x9b9b9b9b
.word 0x9bbb9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x979b9b9b
.word 0x97979797
.word 0x97979797
.word 0x37379797
.word 0x97979797
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x37973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b9b
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0xbb9b9b9b
.word 0xbbbbbbbb
.word 0x9b9bbbbb
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x97979797
.word 0x97979797
.word 0x97379797
.word 0x97979797
.word 0x33333397
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x97373333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x97373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b979b9b
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0xbbbbbbbb
.word 0x9b9bbbbb
.word 0x9b9b9b9b
.word 0xbbbb9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x979b9b9b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x33333737
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333733
.word 0x37373333
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b97
.word 0x97979797
.word 0x97979797
.word 0x9b9b9797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0xbbbbbb9b
.word 0x9b9bbbbb
.word 0x9b9b9b9b
.word 0xbbbb9b9b
.word 0x9b9b9bbb
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x33339797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x33333333
.word 0x37373333
.word 0x37373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b97
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0xbbbb9b9b
.word 0x9b9bbbbb
.word 0x9b9b9b9b
.word 0xbbbbbb9b
.word 0x9b9b9bbb
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x97979b9b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37379797
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x37373333
.word 0x37373733
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9797
.word 0x9797979b
.word 0x97979797
.word 0x979b9b9b
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9bbbbb
.word 0xbbbb9b9b
.word 0xbb9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x979b9b9b
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x37979797
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373733
.word 0x37373737
.word 0x37373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x979b9b9b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b97
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9bbbbbbb
.word 0xbbbb9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x979b9b9b
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x33333797
.word 0x33333333
.word 0x33333333
.word 0x32323333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373733
.word 0x37333737
.word 0x37373733
.word 0x37373737
.word 0x97973797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x979b9b9b
.word 0x9b9b9b97
.word 0x9b9b9b9b
.word 0x9bbbbb9b
.word 0xbb9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x37333737
.word 0x33333333
.word 0x32323333
.word 0x05050504
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373733
.word 0x33373333
.word 0x37333337
.word 0x97373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979b97
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b97
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b979b9b
.word 0x97979797
.word 0x92979797
.word 0x33373337
.word 0x2e333333
.word 0x05050404
.word 0x25292905
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x33373333
.word 0x37373733
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b97
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9797
.word 0x9b9b9b9b
.word 0x9b9b979b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9797979b
.word 0x96979797
.word 0x323337bb
.word 0x04040409
.word 0xb6250504
.word 0x95bbbabb
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373733
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979b97
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x979b9b9b
.word 0x9b9b9b9b
.word 0x9b97979b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9bbbbb9b
.word 0x97979b9b
.word 0x96059797
.word 0x050409bb
.word 0xba290404
.word 0xbabbbaba
.word 0x0890baba
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x37373733
.word 0x37373337
.word 0x37973737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b979b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b979b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b979b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0xbbbbbb9b
.word 0x9bbbbb9b
.word 0x979b9b9b
.word 0x04969797
.word 0x29910404
.word 0xbabababb
.word 0xbabababa
.word 0x080404b6
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x37979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b97
.word 0x9b9b9b9b
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9bbb9b9b
.word 0x9bbbbb9b
.word 0x979b9b9b
.word 0x052d0400
.word 0x9691ba29
.word 0xbabababa
.word 0xbabababb
.word 0x04282891
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x33373333
.word 0x37373737
.word 0x33373737
.word 0x97373737
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979b9b
.word 0x9b9b979b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9bbbbb9b
.word 0x9bbbbbbb
.word 0x04049b9b
.word 0xba8d0404
.word 0x9291baba
.word 0xbabababa
.word 0xbbbababa
.word 0x0004042c
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373333
.word 0x37373337
.word 0x37373337
.word 0x37373737
.word 0x37379737
.word 0x97373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b979b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b97
.word 0xbb9b9b9b
.word 0x9b9bbbbb
.word 0x04040400
.word 0xb691ba92
.word 0x9291baba
.word 0xbabababa
.word 0xbabababa
.word 0x00000028
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x37333733
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9797
.word 0x9b979b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0xbbbb9b9b
.word 0x0404bbbb
.word 0xba920404
.word 0x8d91baba
.word 0xbb91baba
.word 0xbabababa
.word 0xbabbbaba
.word 0xbfbf0004
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x37373333
.word 0x37373333
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9797
.word 0x97979b9b
.word 0x9b979b97
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x0404049b
.word 0x96baba92
.word 0xb691baba
.word 0xbf91baba
.word 0xbabababa
.word 0xbabababa
.word 0xbaba0029
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333733
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x979b9b9b
.word 0x97979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x049b9b9b
.word 0xb6920404
.word 0xb6bababa
.word 0xba91baba
.word 0xbfba91ba
.word 0xbabababa
.word 0xbabbbaba
.word 0xba2dbaba
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x33373333
.word 0x37373737
.word 0x97373737
.word 0x97979737
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979b97
.word 0x97979797
.word 0x9b9b9b97
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x0404929b
.word 0xb6b69691
.word 0xbab6b6b6
.word 0xba91baba
.word 0xbfba91ba
.word 0xbabababa
.word 0x8dbababa
.word 0x04280029
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x97373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979b97
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x92040404
.word 0xb6969696
.word 0xbababab6
.word 0xbf9191ba
.word 0xbfbababa
.word 0x96bababa
.word 0x00040004
.word 0x04040400
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x37333337
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97379737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b9b9b97
.word 0x9b9b9b9b
.word 0x049b9b9b
.word 0x96929205
.word 0xb6b69296
.word 0xbaba92b6
.word 0xbf9291ba
.word 0xbfbaba91
.word 0x04048d00
.word 0x28040400
.word 0x00042d29
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373337
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x0404049b
.word 0x96969291
.word 0xb6b69696
.word 0xb6ba92b6
.word 0xbf91baba
.word 0x042900ba
.word 0x04040000
.word 0x2d2d2d29
.word 0x0400048d
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x97373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x92920400
.word 0x96969691
.word 0xb6b69692
.word 0xbaba92b6
.word 0x2900ba96
.word 0x04040004
.word 0x2d2d2928
.word 0x91919131
.word 0x040004ba
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x37973797
.word 0x37973737
.word 0x97379737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x9b979b9b
.word 0x049b9b9b
.word 0x92929204
.word 0x969696ba
.word 0xb6b6b696
.word 0xbaba92b6
.word 0x00000004
.word 0x2d2d2804
.word 0x9191912d
.word 0xbababb91
.word 0x000024ba
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x33373333
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97973737
.word 0x37379797
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979b97
.word 0x97979797
.word 0x04049b97
.word 0x92929292
.word 0x969696bf
.word 0xb6b69696
.word 0x042929ba
.word 0x2d242800
.word 0x91918d2d
.word 0xbaba9191
.word 0xbabababa
.word 0x8d00baba
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373333
.word 0x37373737
.word 0x37373337
.word 0x37373737
.word 0x37373737
.word 0x97373737
.word 0x37373797
.word 0x37379737
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0xba290432
.word 0x92929292
.word 0x969696ba
.word 0x00969696
.word 0x04000004
.word 0x918d2d28
.word 0x92919191
.word 0xbabababa
.word 0xbabababa
.word 0xbababa24
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x33373333
.word 0x37373333
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97973737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x05979797
.word 0xbf928d04
.word 0x92929292
.word 0x96969691
.word 0x00000096
.word 0x2d290404
.word 0x9191918d
.word 0xbaba9691
.word 0xbabababa
.word 0xbabababa
.word 0xbabb0000
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373337
.word 0x37333333
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x04009797
.word 0xbe929292
.word 0x96929292
.word 0x0092962d
.word 0x04240000
.word 0x91918d2d
.word 0xb6919191
.word 0xbabababa
.word 0xbabababa
.word 0x04bababa
.word 0xbaba0000
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373733
.word 0x37333333
.word 0x37373337
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x92040997
.word 0xbe929292
.word 0x92929292
.word 0x002d8d92
.word 0x2d2d0404
.word 0x91919191
.word 0xbabab692
.word 0xbabababa
.word 0x28bababa
.word 0x00000424
.word 0xbaba0404
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37373737
.word 0x37373737
.word 0x37373337
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x92910497
.word 0xbe929292
.word 0x96929292
.word 0x04000404
.word 0x91912d29
.word 0x92929191
.word 0xbabababa
.word 0xbabababa
.word 0x00002828
.word 0x29040429
.word 0xbaba2900
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373333
.word 0x33373333
.word 0x37333333
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37973737
.word 0x97973797
.word 0x97979797
.word 0x97979797
.word 0x92929204
.word 0x95929292
.word 0x00009292
.word 0x00290400
.word 0x9191912d
.word 0xbaba9191
.word 0xbabababa
.word 0x00bababa
.word 0x2d04092d
.word 0x29042929
.word 0xbaba2e29
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x33333333
.word 0x37373337
.word 0x37373737
.word 0x37373737
.word 0x37373337
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x97979797
.word 0x04979797
.word 0x92929292
.word 0x91929292
.word 0x04000096
.word 0x2d2d2d28
.word 0x91919100
.word 0xbababa92
.word 0xba24baba
.word 0x05bababa
.word 0x29042d2d
.word 0x2d292d29
.word 0xbaba292d
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x33373337
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37333737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979737
.word 0x92049797
.word 0x92929292
.word 0x04929292
.word 0x2d280400
.word 0x9191912d
.word 0x96919104
.word 0x04babab6
.word 0x2d090004
.word 0x29bababa
.word 0x2d042d2e
.word 0x2d292d2d
.word 0xbaba2d2d
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333733
.word 0x33333333
.word 0x33373737
.word 0x37373733
.word 0x33373737
.word 0x33373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37379737
.word 0x37373737
.word 0x92040097
.word 0x92929292
.word 0x00009692
.word 0x912d2d04
.word 0x91919191
.word 0xbab6922d
.word 0x000428ba
.word 0x00292900
.word 0x8dbababa
.word 0x2d2d2d32
.word 0x2d292d2d
.word 0x24282d2d
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x33373333
.word 0x37373737
.word 0x37333333
.word 0x33373737
.word 0x33373333
.word 0x33373337
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92920437
.word 0x92929292
.word 0x28040000
.word 0x91912d2d
.word 0x92919191
.word 0x28969629
.word 0x29290400
.word 0x2d2d2904
.word 0x92bababa
.word 0x2d962e92
.word 0x04042d2d
.word 0xbababb92
.word 0x33333333
.word 0x33333733
.word 0x33373333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333733
.word 0x33333333
.word 0x37333333
.word 0x33333733
.word 0x37373333
.word 0x33333737
.word 0x33373733
.word 0x33333337
.word 0x37333337
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92929204
.word 0x28929292
.word 0x2d2d0400
.word 0x91919191
.word 0x91929192
.word 0x04009604
.word 0x2d292929
.word 0x922e2d04
.word 0xbbbababa
.word 0x04049292
.word 0xbababa96
.word 0xbabababa
.word 0x37333733
.word 0x33373733
.word 0x33333333
.word 0x33373333
.word 0x33333333
.word 0x33333737
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373733
.word 0x37373333
.word 0x33333337
.word 0x37333333
.word 0x37333337
.word 0x37373337
.word 0x37333737
.word 0x37333337
.word 0x37373737
.word 0x32373737
.word 0x92929204
.word 0x00049292
.word 0x91912d28
.word 0x91919191
.word 0x91929192
.word 0x29299604
.word 0x2d2d9629
.word 0x2d2e2d05
.word 0x04bababa
.word 0xbababa29
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x33333333
.word 0x33373737
.word 0x33333337
.word 0x37333333
.word 0x33333333
.word 0x33373333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x37373333
.word 0x33333733
.word 0x33373333
.word 0x37373737
.word 0x33333737
.word 0x37373333
.word 0x33373337
.word 0x37373733
.word 0x37373737
.word 0x05292937
.word 0x92929292
.word 0x2d28002d
.word 0x9191918d
.word 0x91929192
.word 0x92960491
.word 0x2d299604
.word 0x2d2d092d
.word 0x2d2d2d05
.word 0xbaba9104
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x33373737
.word 0x33333733
.word 0x37373333
.word 0x33373333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x33333337
.word 0x33333333
.word 0x33373333
.word 0x33333333
.word 0x37373337
.word 0x37333333
.word 0x33333733
.word 0x37333737
.word 0x37373733
.word 0x37373737
.word 0x37373733
.word 0x37373737
.word 0x92059a37
.word 0x00929292
.word 0x912d0400
.word 0x91919191
.word 0x04919191
.word 0x92960000
.word 0x2e2d9600
.word 0x2e2d002e
.word 0xba2d0404
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x33333337
.word 0x33333333
.word 0x37373333
.word 0x33373337
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x37333333
.word 0x33333333
.word 0x37333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x37333733
.word 0x37373337
.word 0x37333337
.word 0x33333337
.word 0x33333333
.word 0x37333333
.word 0x37373737
.word 0x37333737
.word 0x33333337
.word 0x37373733
.word 0x37373737
.word 0x92059637
.word 0x00009292
.word 0x91912d24
.word 0x92919191
.word 0x00042892
.word 0x91962929
.word 0x2e2d9625
.word 0x0429092e
.word 0xbababa96
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x33333737
.word 0x37333333
.word 0x33333733
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333733
.word 0x33333733
.word 0x37333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33373733
.word 0x37333333
.word 0x33333333
.word 0x33373737
.word 0x37373737
.word 0x37333733
.word 0x33373733
.word 0x37373333
.word 0x37373733
.word 0x33373737
.word 0x92922937
.word 0x28000492
.word 0x9191912d
.word 0x91919192
.word 0x04040004
.word 0x91962d29
.word 0x322d962d
.word 0xba962904
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x33373333
.word 0x33333333
.word 0x33333733
.word 0x33333333
.word 0x33333337
.word 0x37333333
.word 0x33333333
.word 0x33333337
.word 0x33333333
.word 0x33333337
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x37333733
.word 0x33333737
.word 0x33373733
.word 0x33333333
.word 0x33333733
.word 0x37373333
.word 0x37373737
.word 0x37373737
.word 0x33373737
.word 0x37373333
.word 0x37373737
.word 0x92920537
.word 0x8d28002d
.word 0x91919191
.word 0x00049291
.word 0x29090029
.word 0x91962d2d
.word 0x8d04962d
.word 0xbabab6ba
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373733
.word 0x37373737
.word 0x37333737
.word 0x37333737
.word 0x33333333
.word 0x37333333
.word 0x37373333
.word 0x33333737
.word 0x33333337
.word 0x33333733
.word 0x33333333
.word 0x33333333
.word 0x33333333
.word 0x33333733
.word 0x33333733
.word 0x33333737
.word 0x33333337
.word 0x33373333
.word 0x37373333
.word 0x33333333
.word 0x33333337
.word 0x33333733
.word 0x37373337
.word 0x37333737
.word 0x33333737
.word 0x33333337
.word 0x37373737
.word 0x04919232
.word 0x91912900
.word 0x91919191
.word 0x29009292
.word 0x292d0429
.word 0x91962d2d
.word 0xbab69204
.word 0xbabab6ba
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37333733
.word 0x37373737
.word 0x33333733
.word 0x33333333
.word 0x33333333
.word 0x33333337
.word 0x37333333
.word 0x33333333
.word 0x37333333
.word 0x33333333
.word 0x33333337
.word 0x33333733
.word 0x33333333
.word 0x33333333
.word 0x37333333
.word 0x33373337
.word 0x37333337
.word 0x37333333
.word 0x33333733
.word 0x33333333
.word 0x37373333
.word 0x37373333
.word 0x37373337
.word 0x37373337
.word 0x37373333
.word 0x37373737
.word 0x04049229
.word 0x91918d29
.word 0x92919191
.word 0x29329192
.word 0x2d2d292d
.word 0x91042e2d
.word 0xb6b69696
.word 0xbab6b6b6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37379737
.word 0x33373737
.word 0x37373737
.word 0x33373733
.word 0x37333733
.word 0x37333733
.word 0x33373733
.word 0x33333337
.word 0x33333337
.word 0x33373333
.word 0x33333333
.word 0x37333337
.word 0x33373733
.word 0x33333333
.word 0x33333737
.word 0x37333737
.word 0x37333337
.word 0x37333737
.word 0x37373737
.word 0x33333737
.word 0x33333337
.word 0x33373737
.word 0x37333733
.word 0x33333733
.word 0x37373737
.word 0x37333333
.word 0x37373733
.word 0x29000409
.word 0x91919191
.word 0x92049191
.word 0x2d299192
.word 0x2d2d322d
.word 0x96969104
.word 0xb6b69696
.word 0xbababab6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97979797
.word 0x37373797
.word 0x37373737
.word 0x33373737
.word 0x37373737
.word 0x37333333
.word 0x37373733
.word 0x37333737
.word 0x37373333
.word 0x33333733
.word 0x33333733
.word 0x37333337
.word 0x33373733
.word 0x33373333
.word 0x37373733
.word 0x33373733
.word 0x37373337
.word 0x37373733
.word 0x33333737
.word 0x37373333
.word 0x37373337
.word 0x37333737
.word 0x37373733
.word 0x33373333
.word 0x37373337
.word 0x37373737
.word 0x37373737
.word 0x91290091
.word 0x92919191
.word 0x91290491
.word 0x2d009192
.word 0x9104922d
.word 0x96969692
.word 0xb6ba9696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97979797
.word 0x97979797
.word 0x37373737
.word 0x37373737
.word 0x33373737
.word 0x37333337
.word 0x33333733
.word 0x33333337
.word 0x33333333
.word 0x33373737
.word 0x33333333
.word 0x33373737
.word 0x33333733
.word 0x37333737
.word 0x33333733
.word 0x37333333
.word 0x33333737
.word 0x37333737
.word 0x37373333
.word 0x37333733
.word 0x33333737
.word 0x37373737
.word 0x33333337
.word 0x33373737
.word 0x37373737
.word 0x37373737
.word 0x33923733
.word 0x91912800
.word 0x91929191
.word 0x92290004
.word 0x2d009292
.word 0x96922d29
.word 0x96969696
.word 0xb6b69696
.word 0xbabab696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97979797
.word 0x97973797
.word 0x37979797
.word 0x37373737
.word 0x37373737
.word 0x33373737
.word 0x37333733
.word 0x37333337
.word 0x37333737
.word 0x33373733
.word 0x37333737
.word 0x33373737
.word 0x37373733
.word 0x33373337
.word 0x37333337
.word 0x37373737
.word 0x33373337
.word 0x37373737
.word 0x33373737
.word 0x37373733
.word 0x33373737
.word 0x33333333
.word 0x37373337
.word 0x33333737
.word 0x37333737
.word 0x37373737
.word 0x00923333
.word 0x91919128
.word 0x002d9191
.word 0x92290400
.word 0x00009292
.word 0x96969291
.word 0x96969696
.word 0xb6ba9696
.word 0xb6bab6b6
.word 0xbabab6ba
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97979797
.word 0x37979797
.word 0x97979737
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37333733
.word 0x37373733
.word 0x33373333
.word 0x37333333
.word 0x33373733
.word 0x37373333
.word 0x37373333
.word 0x37373733
.word 0x37333737
.word 0x37333333
.word 0x37373333
.word 0x37373737
.word 0x37373737
.word 0x37373333
.word 0x37373737
.word 0x33373737
.word 0x37333733
.word 0x37373737
.word 0x33373737
.word 0x33333737
.word 0x28043333
.word 0x91919191
.word 0x04002891
.word 0x92290429
.word 0x91910092
.word 0x96929292
.word 0x96969696
.word 0xbab69696
.word 0xb6babab6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x04bababa
.word 0xba000404
.word 0x97979797
.word 0x97979797
.word 0x97979737
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37333337
.word 0x37373737
.word 0x33333737
.word 0x37333737
.word 0x37333737
.word 0x37373733
.word 0x37373733
.word 0x37373333
.word 0x37373737
.word 0x37333737
.word 0x33333737
.word 0x37373737
.word 0x37373337
.word 0x37373737
.word 0x37373733
.word 0x37333733
.word 0x37373737
.word 0x33373733
.word 0x37373733
.word 0x37333737
.word 0x2d040037
.word 0x91929291
.word 0x0429008d
.word 0x91290029
.word 0x92919229
.word 0x96969292
.word 0x96969696
.word 0xb6b69696
.word 0xbab6b696
.word 0xbabababa
.word 0xbabababa
.word 0x2dbababa
.word 0x00000404
.word 0xba2d0404
.word 0x97979797
.word 0x97979797
.word 0x37979797
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x33373337
.word 0x33373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373733
.word 0x37373333
.word 0x37373737
.word 0x33373733
.word 0x37373737
.word 0x37373737
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x33333737
.word 0x37373733
.word 0x33373737
.word 0x912d0037
.word 0x92929291
.word 0x2d090091
.word 0x91000029
.word 0x92929191
.word 0x96969692
.word 0x04969696
.word 0xb6969696
.word 0xbab6b6b6
.word 0xbababab6
.word 0xb6bababa
.word 0x00002828
.word 0x04040000
.word 0xba2e2e2d
.word 0x97979797
.word 0x97979797
.word 0x37379797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373337
.word 0x37373737
.word 0x37373737
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37333737
.word 0x37373737
.word 0x37373737
.word 0x37333737
.word 0x37373737
.word 0x33373337
.word 0x91912404
.word 0x91289291
.word 0x96090492
.word 0x92910029
.word 0x92919192
.word 0x96929692
.word 0x04969696
.word 0xb6b69696
.word 0xbab6b6b6
.word 0xbabababa
.word 0xbaba9191
.word 0x292e2925
.word 0x04000000
.word 0xba2e2e2e
.word 0x97979797
.word 0x97979797
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x33333737
.word 0x37373337
.word 0x37333737
.word 0x37373737
.word 0x33373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373733
.word 0x37373737
.word 0x37373737
.word 0x37333737
.word 0x37373337
.word 0x37333737
.word 0x37373737
.word 0x92919104
.word 0x91002991
.word 0x32290492
.word 0x91929191
.word 0x92929192
.word 0x96929692
.word 0x04919696
.word 0xb6969696
.word 0x96b6b6ba
.word 0x000496b6
.word 0xbabababa
.word 0x2e2d2d8d
.word 0x04090509
.word 0xba323232
.word 0x37973737
.word 0x97973797
.word 0x97979797
.word 0x97979737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37333737
.word 0x37373733
.word 0x37373337
.word 0x33373737
.word 0x37373737
.word 0x37373737
.word 0x37373337
.word 0x04333733
.word 0x91919129
.word 0x91040091
.word 0x91000492
.word 0x92929191
.word 0x92929191
.word 0x96929692
.word 0x00919696
.word 0xb6969696
.word 0x049696b6
.word 0x29290004
.word 0xbabababa
.word 0x2e2d2dbb
.word 0x0509092d
.word 0x31323232
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x33373737
.word 0x37373737
.word 0x37373733
.word 0x37333737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x33333733
.word 0x37373737
.word 0x37373737
.word 0x28333737
.word 0x91929191
.word 0x91050004
.word 0x92910491
.word 0x92929291
.word 0x92919292
.word 0x96929692
.word 0x04919696
.word 0x96969696
.word 0x00000496
.word 0x2e322d00
.word 0xbabababa
.word 0x2e2d2eba
.word 0x00090996
.word 0x2d329232
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37333737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x33373337
.word 0x2d043737
.word 0x04929291
.word 0x91050500
.word 0x91929108
.word 0x91929292
.word 0x92929191
.word 0x04969292
.word 0x04919131
.word 0x04049696
.word 0x00040000
.word 0x32322e04
.word 0xbabababa
.word 0x2e3232ba
.word 0x05090929
.word 0x04323292
.word 0x37373337
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x09373737
.word 0x37373791
.word 0x37372e37
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91043737
.word 0x29049292
.word 0x2d050929
.word 0x92919191
.word 0x91919192
.word 0x92919291
.word 0x00929292
.word 0x29919196
.word 0x2900912d
.word 0x2d04042d
.word 0x32322d2e
.word 0xbabababa
.word 0x2e9232ba
.word 0x32920909
.word 0x04323292
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x2d370937
.word 0x09322d28
.word 0x3737972d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91290537
.word 0x05289291
.word 0x91910509
.word 0x91919191
.word 0x91919291
.word 0x92929291
.word 0x00969292
.word 0x2d2d9100
.word 0x92329696
.word 0x2d2d0492
.word 0x32322d2d
.word 0xbabababa
.word 0x2e2d32ba
.word 0x09ba0929
.word 0x04323292
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x282d3737
.word 0x91089228
.word 0x37373208
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91910037
.word 0x092d9191
.word 0x91919105
.word 0x92919291
.word 0x91929191
.word 0x92929292
.word 0x25929292
.word 0x96910004
.word 0x92929696
.word 0x2e2e0492
.word 0x3232922e
.word 0xbabababa
.word 0x2e9292ba
.word 0x09092909
.word 0x0432929a
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04083637
.word 0x962e372c
.word 0x37379604
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92912833
.word 0x092d9204
.word 0x91919292
.word 0x91919191
.word 0x91919192
.word 0x92919292
.word 0x04049292
.word 0x92912905
.word 0x92049696
.word 0x2e2e0592
.word 0x3232bf2e
.word 0xbabababa
.word 0x2e3192ba
.word 0x92292905
.word 0x8d04292d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373137
.word 0x04280437
.word 0x2c96912c
.word 0x37333304
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x9191242a
.word 0x922d9104
.word 0x92919292
.word 0x92919192
.word 0x92919191
.word 0x92919192
.word 0x04000404
.word 0x92912d04
.word 0x92009696
.word 0x2e320492
.word 0x2e2e962e
.word 0xbabababa
.word 0xbb2e92ba
.word 0xba910429
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91320937
.word 0x04042c33
.word 0x302c282c
.word 0x2d052d2c
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04912d05
.word 0x91049100
.word 0x91929192
.word 0x92929191
.word 0x91919192
.word 0x04919191
.word 0x04290000
.word 0x92910404
.word 0x92299696
.word 0x2e2e0432
.word 0x2d2d042e
.word 0xbabababa
.word 0x962d04ba
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x922c3732
.word 0x04040408
.word 0x04280804
.word 0x2908952c
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04919100
.word 0x91910400
.word 0x91919192
.word 0x92919192
.word 0x91919191
.word 0x00000491
.word 0x00042d04
.word 0x96000000
.word 0x32259696
.word 0x2e320592
.word 0x2d2d092e
.word 0xbaba9692
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x2c2c3796
.word 0x04042c04
.word 0x2c040808
.word 0x292d2c31
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x00289100
.word 0x91919200
.word 0x91919192
.word 0x91919191
.word 0x28919191
.word 0x2d292d91
.word 0x00000004
.word 0x00000000
.word 0x96299696
.word 0x2e322592
.word 0x2d04052e
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x042d3796
.word 0x0808282c
.word 0x04002c30
.word 0x04042d31
.word 0x37373791
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x00049100
.word 0x92919291
.word 0x91929192
.word 0x91919191
.word 0x91919191
.word 0x2d2d2d91
.word 0x00000000
.word 0x00000000
.word 0x92bb9600
.word 0x002e9632
.word 0xbaba8d29
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x31289709
.word 0x2c042804
.word 0x04040429
.word 0x09042831
.word 0x97973728
.word 0x37373737
.word 0x37379797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x2d299100
.word 0x92929191
.word 0x91919191
.word 0x91919191
.word 0x91910004
.word 0x2e2d9192
.word 0x00000004
.word 0x00040400
.word 0x92bf9604
.word 0xb696292d
.word 0xbabab6b6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04040033
.word 0x29040008
.word 0x04000404
.word 0x282d0828
.word 0x97970028
.word 0x37373797
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92299100
.word 0x91929191
.word 0x91919192
.word 0x04919192
.word 0x91910400
.word 0x2e2d9191
.word 0x04000004
.word 0x04290904
.word 0x91049696
.word 0xbabab696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04042897
.word 0x04040408
.word 0x04040400
.word 0x04042c91
.word 0x97952828
.word 0x97379709
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91910400
.word 0x92929191
.word 0x91929191
.word 0x04049191
.word 0x91912900
.word 0x322d9191
.word 0x29000004
.word 0x29292909
.word 0x96969696
.word 0xbab6bab6
.word 0xbabab6ba
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37323737
.word 0x29049632
.word 0x0408322c
.word 0x08000000
.word 0x2c082d28
.word 0x31912828
.word 0x97979604
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37973737
.word 0x37373737
.word 0x37373737
.word 0x92920500
.word 0x91929292
.word 0x91919191
.word 0x29040024
.word 0x91912900
.word 0x32293191
.word 0x29000092
.word 0x29292929
.word 0x96969692
.word 0xbab6bab6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x372e2d37
.word 0x04092832
.word 0x042d082d
.word 0x04040404
.word 0x2d042c04
.word 0x2c080404
.word 0x37373228
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92929100
.word 0x91929291
.word 0x04929191
.word 0x29290900
.word 0x91912904
.word 0x32299191
.word 0x2900292e
.word 0x29292929
.word 0xb6969696
.word 0xb6bab696
.word 0xbab6baba
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x37373797
.word 0x37333237
.word 0x04040404
.word 0x922e3104
.word 0x00042d00
.word 0x95042804
.word 0x2c040428
.word 0x37092d04
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92929205
.word 0x91929191
.word 0x2d919191
.word 0x29962900
.word 0x91920904
.word 0x322d9191
.word 0x29002e2e
.word 0x29292929
.word 0x96969692
.word 0xbab6bab6
.word 0xbab6baba
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979797
.word 0x37379797
.word 0x322e2e37
.word 0x0404282e
.word 0x04049109
.word 0x00000400
.word 0x2d002c04
.word 0x95040404
.word 0x3797322c
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91929191
.word 0x91919292
.word 0x91918d91
.word 0x292d2900
.word 0x912d2904
.word 0x922d9191
.word 0x29002d29
.word 0x29292929
.word 0x96969691
.word 0xbabab6b6
.word 0xbabab6ba
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37979737
.word 0x37379737
.word 0x97979797
.word 0x97979797
.word 0x32099797
.word 0x08040004
.word 0x050a3109
.word 0x04000000
.word 0x04290804
.word 0x04080404
.word 0x37910428
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92919292
.word 0x91919191
.word 0x92919104
.word 0x29002904
.word 0x91292900
.word 0x31299191
.word 0x29002991
.word 0x29292929
.word 0x96969600
.word 0xbababa96
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x00040491
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97373797
.word 0x97979797
.word 0x9b9b9b9b
.word 0x97049797
.word 0x33040400
.word 0x09970504
.word 0x2d000408
.word 0x04093104
.word 0x0404042d
.word 0x97323104
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x29373737
.word 0x92929192
.word 0x04919192
.word 0x92919129
.word 0x29002904
.word 0x91092900
.word 0x91919191
.word 0x08009291
.word 0x29080408
.word 0x96969604
.word 0xbab6b696
.word 0xb6b6b6ba
.word 0xbabababa
.word 0xbabababa
.word 0x00042424
.word 0x2d040900
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97373737
.word 0x97973797
.word 0x97979797
.word 0x9b9b9b97
.word 0x2d089b0d
.word 0x00000404
.word 0x08282c05
.word 0x29000404
.word 0x04053732
.word 0x08080804
.word 0x282d2c28
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92373737
.word 0x92919192
.word 0x00049192
.word 0x92919129
.word 0x29002909
.word 0x9129292d
.word 0x91919191
.word 0x04049291
.word 0x29040404
.word 0x96969629
.word 0xbab6b696
.word 0xb6bababa
.word 0xbabababa
.word 0x00009128
.word 0x2d2d0404
.word 0x2d2d2d92
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37979737
.word 0x97979737
.word 0x9b9b9797
.word 0x29089b9b
.word 0x05002904
.word 0x04040000
.word 0x04000832
.word 0x04312904
.word 0x2c2c042c
.word 0x2d280000
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91919291
.word 0x29000491
.word 0x91919129
.word 0x29042905
.word 0x91910492
.word 0x91919191
.word 0x04299291
.word 0x04040404
.word 0x96969629
.word 0xb6969696
.word 0xbab6bab6
.word 0xba919191
.word 0x2d2dbaba
.word 0x2d2d042d
.word 0x2d2d2d2d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97973737
.word 0x97979737
.word 0x9b979797
.word 0x042e9b9b
.word 0x28050404
.word 0x04003204
.word 0x04040400
.word 0x0428912c
.word 0x04049504
.word 0x08043004
.word 0x37373732
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x92373737
.word 0x91929192
.word 0x09040004
.word 0x91919129
.word 0x29042904
.word 0x9191912d
.word 0x91919191
.word 0x04299292
.word 0x04040404
.word 0x96969604
.word 0xbaba9696
.word 0x000496b6
.word 0xbababa00
.word 0x2d2dbaba
.word 0x2d2d042d
.word 0x2d2d2d2d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97979737
.word 0x97379797
.word 0x97973737
.word 0x0d2e979b
.word 0x9132042d
.word 0x04042c00
.word 0x042c2c2c
.word 0x9a002c00
.word 0x2d990428
.word 0x04303000
.word 0x3737372d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91919191
.word 0x09000029
.word 0x91929129
.word 0x2d042929
.word 0x91919191
.word 0x92919191
.word 0x00299292
.word 0x91040404
.word 0x96969604
.word 0x04969696
.word 0x2d040000
.word 0xbababa2d
.word 0x2d2dbaba
.word 0x2d2d292d
.word 0x2d2d962d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97973737
.word 0x97979797
.word 0x37979797
.word 0x97379797
.word 0x092d3737
.word 0x282d0409
.word 0x04040009
.word 0x282c0400
.word 0x28280408
.word 0x91080495
.word 0x2c2c042c
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91919291
.word 0x2900042d
.word 0x91919129
.word 0x91912d96
.word 0x91919191
.word 0x92919191
.word 0x00929292
.word 0x91040000
.word 0x96969600
.word 0x04000024
.word 0x2d052d2d
.word 0xbababa2d
.word 0x2d2dbaba
.word 0x2d2d092d
.word 0x2d2d962d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97973737
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x32372e36
.word 0x00372c2c
.word 0x04320804
.word 0x04040404
.word 0x95280430
.word 0x282c3000
.word 0x042c042c
.word 0x37373704
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91049191
.word 0x2900042d
.word 0x2d919109
.word 0x91919191
.word 0x91919191
.word 0x92919191
.word 0x00929692
.word 0x91040400
.word 0x00912800
.word 0x2d042d04
.word 0x2d962d2d
.word 0xbababa2d
.word 0x2d2dbaba
.word 0x2d2d052d
.word 0x2d2d092d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37979737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x05040933
.word 0x00320431
.word 0x31000404
.word 0x04042c95
.word 0x04960404
.word 0x302c2c28
.word 0x31040004
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91049191
.word 0x2d04042d
.word 0x912d9105
.word 0x91919191
.word 0x91919191
.word 0x92919191
.word 0x92929292
.word 0x29000000
.word 0x29969604
.word 0x2d042d2d
.word 0x2d962d2d
.word 0xbababa2d
.word 0x2d2dbaba
.word 0x2d2d052d
.word 0x2d2d052d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37379737
.word 0x37379737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x08052d37
.word 0x00009504
.word 0x00009708
.word 0x04040031
.word 0x91040804
.word 0x04082804
.word 0x04040430
.word 0x37379137
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91040491
.word 0x2d04082d
.word 0x9191912d
.word 0x91919191
.word 0x91919191
.word 0x92919191
.word 0x92919292
.word 0x91000000
.word 0x00969692
.word 0x2d042d2d
.word 0x2d042d2d
.word 0xbaba962d
.word 0x2d2ebaba
.word 0x2d2d052d
.word 0x2d2d052d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37973737
.word 0x97373797
.word 0x37373737
.word 0x37379737
.word 0x36373737
.word 0x372d2d37
.word 0x04042997
.word 0x3237002c
.word 0x04000404
.word 0x00000428
.word 0x28080404
.word 0x95040428
.word 0x08289131
.word 0x322c3731
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91040491
.word 0x2d04042d
.word 0x9191912d
.word 0x91919191
.word 0x91919191
.word 0x92919191
.word 0x04919292
.word 0x96000000
.word 0x00969692
.word 0x2d042d2d
.word 0x2d042d2d
.word 0xbaba042d
.word 0x2d2dbaba
.word 0x2d2d042d
.word 0x2d2d092d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37379737
.word 0x37373737
.word 0x37373797
.word 0x3737312d
.word 0x2d373737
.word 0x0937082c
.word 0x0829052e
.word 0x32320004
.word 0x00043300
.word 0x0000042c
.word 0x00040404
.word 0x04040404
.word 0x08280400
.word 0x2c082c28
.word 0x37373704
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x912e0404
.word 0x29090991
.word 0x91919191
.word 0x91919191
.word 0x91919191
.word 0x91919191
.word 0x04000491
.word 0x96000000
.word 0x25969692
.word 0x2d002d2d
.word 0x2d052d2d
.word 0xbaba042d
.word 0x2d96baba
.word 0x2d2d042d
.word 0x922d092d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97973797
.word 0x97979797
.word 0x97379797
.word 0x9131372d
.word 0x37373231
.word 0x2d323737
.word 0x312d0896
.word 0x04040409
.word 0x372e0804
.word 0x04040800
.word 0x0408042c
.word 0x08000000
.word 0x282c2804
.word 0x08282c08
.word 0x282c0d08
.word 0x37373796
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x912e0428
.word 0x912d0992
.word 0x91919191
.word 0x91919191
.word 0x91919191
.word 0x04919191
.word 0x09000000
.word 0x92000000
.word 0x25969692
.word 0x2d052d2d
.word 0x2d042d2d
.word 0xbaba922d
.word 0x2e2ebaba
.word 0x049605bb
.word 0xbaba2d04
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x95373797
.word 0x28969132
.word 0x37379532
.word 0x97283737
.word 0x04960429
.word 0x30302d08
.word 0x97092c2c
.word 0x2804042d
.word 0x04283104
.word 0x31300004
.word 0x29280091
.word 0x04040028
.word 0x312e3104
.word 0x3737972d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x912e0429
.word 0x91912992
.word 0x91919191
.word 0x91919191
.word 0x91919191
.word 0x29242d91
.word 0x09090429
.word 0x91000000
.word 0x8d969692
.word 0x2d922d2d
.word 0x2d042d2d
.word 0xbaba322d
.word 0x0404baba
.word 0xbababa8d
.word 0xbabababa
.word 0x97979797
.word 0x37979797
.word 0x37373737
.word 0x37373737
.word 0x97973737
.word 0x97379797
.word 0x94373737
.word 0x90993094
.word 0x92952c28
.word 0x08282d36
.word 0x042d9108
.word 0x2c082c04
.word 0x08083290
.word 0x00082c04
.word 0x2c040808
.word 0x04040004
.word 0x2d002c04
.word 0x042d042c
.word 0x042d082d
.word 0x379a092d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04373737
.word 0x912e042d
.word 0x91919104
.word 0x91919191
.word 0x91919191
.word 0x2d919191
.word 0x292d9191
.word 0x09090029
.word 0x31000004
.word 0xbf969692
.word 0x2d962d2d
.word 0x2d042d2d
.word 0xbab62e2d
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97973797
.word 0x97979797
.word 0x97979797
.word 0x37379797
.word 0x37373737
.word 0x95373737
.word 0x08313737
.word 0x9530312c
.word 0x30902c95
.word 0x04323237
.word 0x09283108
.word 0x2c282828
.word 0x902c2c28
.word 0x0404902c
.word 0x0404042c
.word 0x04040404
.word 0x30912c91
.word 0x2c040400
.word 0x042c0895
.word 0x37379631
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04373737
.word 0x912e042d
.word 0x91919191
.word 0x91919191
.word 0x91919191
.word 0x91002891
.word 0x292d9191
.word 0x09090429
.word 0x31290000
.word 0xbf969692
.word 0x2d2d2d2d
.word 0x0404962d
.word 0xbabab62d
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37979797
.word 0x37979797
.word 0x96373737
.word 0x2c049196
.word 0x28950400
.word 0x302c0490
.word 0x2c092d2c
.word 0x2c2c0828
.word 0x0428082c
.word 0x04040808
.word 0x082d0804
.word 0x08952800
.word 0x00002830
.word 0x2d00312c
.word 0x08042d08
.word 0x09050431
.word 0x3737312d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04373737
.word 0x912e042d
.word 0x91919191
.word 0x91919191
.word 0x91919191
.word 0x91000004
.word 0x2d2d9191
.word 0x09090029
.word 0x91040004
.word 0xbf969692
.word 0x04923232
.word 0xb6962d24
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373737
.word 0x37373797
.word 0x97979797
.word 0x37379737
.word 0x2c919797
.word 0x04049095
.word 0x082c2c08
.word 0x95303030
.word 0x2c282c28
.word 0x04902804
.word 0x2d280404
.word 0x2c040404
.word 0x04080408
.word 0x91040400
.word 0x0400042c
.word 0x04042c00
.word 0x00042c04
.word 0x96090431
.word 0x37379796
.word 0x37973737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04373737
.word 0x912d042d
.word 0x91919191
.word 0x91919191
.word 0x00049191
.word 0x91290004
.word 0x29919191
.word 0x09090029
.word 0x91000000
.word 0xbf969696
.word 0x968d2d00
.word 0xb696b696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37373797
.word 0x97379737
.word 0x37979797
.word 0x37373737
.word 0x08289597
.word 0x302d302c
.word 0x95040408
.word 0x28952c08
.word 0x282c302c
.word 0x9504082c
.word 0x04043008
.word 0x08950800
.word 0x08910408
.word 0x002c0004
.word 0x04042d04
.word 0x04040404
.word 0x2d042c00
.word 0x05372c2c
.word 0x3737372d
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x04373737
.word 0x9191292d
.word 0x91919191
.word 0x91919191
.word 0x29000491
.word 0x912d002d
.word 0x2d919191
.word 0x09090029
.word 0x31000005
.word 0x91969292
.word 0x96969696
.word 0xbab6b696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x37373737
.word 0x37979797
.word 0x37979797
.word 0x97373737
.word 0x97973737
.word 0x04370497
.word 0x2c302c90
.word 0x0404002d
.word 0x302c2899
.word 0x302c3008
.word 0x28042c28
.word 0x002c082c
.word 0x2895912c
.word 0x00040408
.word 0x08282c00
.word 0x00080804
.word 0x0400002d
.word 0x04910400
.word 0x322d2804
.word 0x37373733
.word 0x37373737
.word 0x37379737
.word 0x37373737
.word 0x37373737
.word 0x29373737
.word 0x91912d2d
.word 0x91919191
.word 0x91919191
.word 0x2d000004
.word 0x912d002d
.word 0x2dbb9191
.word 0x09090429
.word 0x2d000092
.word 0x9696922d
.word 0xb6969696
.word 0xbab6b6b6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97973737
.word 0x97373797
.word 0x37979797
.word 0x37373737
.word 0x97373737
.word 0x04293008
.word 0x95082828
.word 0x04090005
.word 0x9995042c
.word 0x2c080808
.word 0x91040491
.word 0x2c300808
.word 0x08080404
.word 0x002d0404
.word 0x08040404
.word 0x29000028
.word 0x04290009
.word 0x0831042c
.word 0x372e9a04
.word 0x37379797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x2d373737
.word 0x9192912d
.word 0x91919191
.word 0x91289191
.word 0x29290029
.word 0x9129002d
.word 0x2dbf9191
.word 0x09099229
.word 0x31000004
.word 0x9696922d
.word 0x96969696
.word 0xbab6bab6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97973797
.word 0x97979797
.word 0x37979797
.word 0x37373737
.word 0x31973737
.word 0x04282890
.word 0x2c28002c
.word 0x0595042c
.word 0x0408042c
.word 0x902c2c04
.word 0x2895282c
.word 0x28042830
.word 0x282c0800
.word 0x0429002c
.word 0x0400002d
.word 0x29000000
.word 0x08000000
.word 0x08042d95
.word 0x33370808
.word 0x97373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x2d373737
.word 0x9191912d
.word 0x91919191
.word 0x91910491
.word 0x2929002d
.word 0x9129002d
.word 0x2d969191
.word 0x29299229
.word 0x9100002d
.word 0x9696962d
.word 0xb6969696
.word 0xb6b6b6b6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x37973737
.word 0x2c2d3737
.word 0x08080430
.word 0x08283005
.word 0x28053004
.word 0x0831082d
.word 0x04302804
.word 0x28952890
.word 0x0404042c
.word 0x04042d04
.word 0x04000095
.word 0x28290000
.word 0x29000000
.word 0x00040000
.word 0x04040004
.word 0x332e2c91
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x2d373737
.word 0x91919191
.word 0x91919191
.word 0x91912d04
.word 0x2929002d
.word 0x912d002d
.word 0x2d919191
.word 0x91312d29
.word 0x91000091
.word 0x96962d2d
.word 0xb6969696
.word 0xb6b6bab6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97979797
.word 0x97979797
.word 0x37979797
.word 0x97373797
.word 0x28319797
.word 0x3737042c
.word 0x04040404
.word 0x2c2d2d04
.word 0x0428292d
.word 0x94300404
.word 0x2c282c08
.word 0x9095902c
.word 0x282c0404
.word 0x002d9600
.word 0x00000400
.word 0x97002829
.word 0x28040400
.word 0x91312804
.word 0x37972c04
.word 0x97373737
.word 0x37373737
.word 0x97373737
.word 0x37379737
.word 0x37373737
.word 0x2d373737
.word 0x91919191
.word 0x04919191
.word 0x9191292d
.word 0x292d002d
.word 0x312d002d
.word 0x2d2d9191
.word 0x9191912d
.word 0x91000092
.word 0x9696042d
.word 0xb6969696
.word 0xb6bababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97379797
.word 0x042e9797
.word 0x04302d28
.word 0x97043292
.word 0x2c292c04
.word 0x04083128
.word 0x0428042c
.word 0x042c2804
.word 0x00992828
.word 0x90000000
.word 0x00040400
.word 0x0004042d
.word 0x32000400
.word 0x04000004
.word 0x00000404
.word 0x97329108
.word 0x37973737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x2d373737
.word 0x91919191
.word 0x04049191
.word 0x91912929
.word 0x292d002d
.word 0x312d002d
.word 0x91912d2d
.word 0x92919191
.word 0x91000092
.word 0x9696922d
.word 0xb6969696
.word 0xb6b6b6b6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97979797
.word 0x97979797
.word 0x37979797
.word 0x97979797
.word 0x08092897
.word 0x902c9028
.word 0x32040905
.word 0x94040904
.word 0x04080404
.word 0x04082d08
.word 0x08952c95
.word 0x2c2c3004
.word 0x04040404
.word 0x00000004
.word 0x00000004
.word 0x00000000
.word 0x04000000
.word 0x04040004
.word 0x97082d00
.word 0x37979797
.word 0x37373797
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91919191
.word 0x29040091
.word 0x91912929
.word 0x292d002d
.word 0x3129002d
.word 0x91913131
.word 0x92919291
.word 0x91000492
.word 0x96962931
.word 0xb6969696
.word 0xb6b6b6ba
.word 0xbabababa
.word 0xbabababa
.word 0x2424baba
.word 0x00000004
.word 0x97979797
.word 0x97979737
.word 0x97979797
.word 0x97979797
.word 0x08042c97
.word 0x0428042c
.word 0x33322d31
.word 0x2828999b
.word 0x04042d00
.word 0x04040404
.word 0x042d0404
.word 0x042d3095
.word 0x2d009090
.word 0x08009200
.word 0x0000282d
.word 0x00040000
.word 0x00000000
.word 0x00000004
.word 0x092d0428
.word 0x37979732
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x91919192
.word 0x292d0091
.word 0x91912929
.word 0x292d002d
.word 0x912d002d
.word 0x91919191
.word 0x92929291
.word 0x91002492
.word 0x96960491
.word 0xb6969696
.word 0xbababab6
.word 0xbabababa
.word 0x042d8dba
.word 0x04000000
.word 0x2d042d2d
.word 0x97979796
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x28099797
.word 0x042c282c
.word 0x37040404
.word 0x04040497
.word 0x28000428
.word 0x08080404
.word 0x04950094
.word 0x28042828
.word 0x9a2d9028
.word 0x00280400
.word 0x00000429
.word 0x00002904
.word 0x00040000
.word 0x2d082891
.word 0x08310404
.word 0x3737972c
.word 0x37373737
.word 0x37379737
.word 0x37373737
.word 0x37373737
.word 0x91373737
.word 0x2d919191
.word 0x052d2991
.word 0x91312929
.word 0x002d042d
.word 0x91312d2d
.word 0x9191912d
.word 0x92919191
.word 0x91009292
.word 0x96960431
.word 0xb6969696
.word 0xb696b6b6
.word 0x963129ba
.word 0x2dbababa
.word 0x2d042d2d
.word 0x2d042d2d
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x2c283297
.word 0x3290082c
.word 0x2d003204
.word 0x00040497
.word 0x95000030
.word 0x95959500
.word 0x08302808
.word 0x08952828
.word 0x0008282c
.word 0x04280400
.word 0x04002900
.word 0x00000400
.word 0x04000008
.word 0x29040000
.word 0x042d2800
.word 0x97042c96
.word 0x37373737
.word 0x37373737
.word 0x37373737
.word 0x97373797
.word 0x92373737
.word 0x04299191
.word 0x052d2d91
.word 0x91912929
.word 0x2d292d2d
.word 0x9191312d
.word 0x91919191
.word 0x92919291
.word 0x91009292
.word 0x96960491
.word 0xb6969696
.word 0x0404b6b6
.word 0xbaba0400
.word 0x2dbababa
.word 0x2d042d2d
.word 0x2d042d2e
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x28089697
.word 0x2c042928
.word 0x97320404
.word 0x28040400
.word 0x04000028
.word 0x002c0404
.word 0x04280008
.word 0x04040404
.word 0x002c3095
.word 0x00292d00
.word 0x00000400
.word 0x00000000
.word 0x00040504
.word 0x04040004
.word 0x2c040400
.word 0x379b2c00
.word 0x97973737
.word 0x97379737
.word 0x37379797
.word 0x97373797
.word 0x92379737
.word 0x04049191
.word 0x292d2d91
.word 0x91312929
.word 0x312d2d04
.word 0x91913191
.word 0x91919191
.word 0x92929191
.word 0x31009292
.word 0x9696002d
.word 0x242d9696
.word 0x2d290000
.word 0xba292d2d
.word 0x2dbababa
.word 0x2e052d2d
.word 0x2d042d2d
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x28283797
.word 0x282c2904
.word 0x97302800
.word 0x28040428
.word 0x2c04952c
.word 0x90950808
.word 0x0495302c
.word 0x0404042d
.word 0x992c9030
.word 0x082e0000
.word 0x00000004
.word 0x00000000
.word 0x00000400
.word 0x28040000
.word 0x28000000
.word 0x37042804
.word 0x37979797
.word 0x37373737
.word 0x37973737
.word 0x37373737
.word 0x92373737
.word 0x29000491
.word 0x962d2d91
.word 0x912d2d2d
.word 0x912d9131
.word 0x91919191
.word 0x91919191
.word 0x92919291
.word 0x31009296
.word 0x2896242d
.word 0x04040024
.word 0x002d2d2d
.word 0xba002d2d
.word 0x96bababa
.word 0x09042d2d
.word 0x2d042d29
.word 0x9797972e
.word 0x97979797
.word 0x97979797
.word 0x04979797
.word 0x282d082c
.word 0x2d2c282c
.word 0x04280404
.word 0x0004042d
.word 0x28300495
.word 0x28282c2c
.word 0x2c952c04
.word 0x042c042c
.word 0x28959504
.word 0x00040499
.word 0x00002d00
.word 0x9a009100
.word 0x00000404
.word 0x08040000
.word 0x2c042d2d
.word 0x9733042c
.word 0x97979737
.word 0x37973797
.word 0x37379797
.word 0x37979737
.word 0x92373737
.word 0x29000091
.word 0x922d2d91
.word 0x3191922d
.word 0x312d9131
.word 0x31919191
.word 0x91919191
.word 0x92929291
.word 0x91009696
.word 0x96912904
.word 0x042d2d00
.word 0x002d2d2d
.word 0xba2d2d2d
.word 0x9bbababa
.word 0x05042d32
.word 0x2d042904
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x04083004
.word 0x2e040829
.word 0x04040497
.word 0x0004042c
.word 0x28302894
.word 0x28082895
.word 0x302c3090
.word 0x0404952c
.word 0x28950899
.word 0x00970491
.word 0x00002c00
.word 0x04280008
.word 0x00000008
.word 0x00040400
.word 0x00080404
.word 0x97319128
.word 0x97379797
.word 0x97979797
.word 0x97979797
.word 0x37973737
.word 0x92973737
.word 0x3200002d
.word 0x092d2d91
.word 0x91912d00
.word 0x91913191
.word 0x91919191
.word 0x91919191
.word 0x92929191
.word 0x04009191
.word 0x9696962d
.word 0x042d2d00
.word 0x042d2d2e
.word 0xba962e2d
.word 0x29bababa
.word 0x00922d32
.word 0x29040000
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x2808042d
.word 0x04282c2c
.word 0x04313204
.word 0x0428042c
.word 0x042c282c
.word 0x042c282c
.word 0x2c999591
.word 0x04293031
.word 0x0404082c
.word 0x0829042c
.word 0x99040004
.word 0x31042c28
.word 0x00090000
.word 0x00040000
.word 0x04040000
.word 0x08910495
.word 0x3797972e
.word 0x97979797
.word 0x37979797
.word 0x97979797
.word 0x92973797
.word 0x92000491
.word 0x042d2d91
.word 0x9191912d
.word 0x91319131
.word 0x91313191
.word 0x91919191
.word 0x04919191
.word 0x00000000
.word 0x9696922d
.word 0x042d2e04
.word 0x042d2e2d
.word 0xba2d2e2e
.word 0x29bababa
.word 0x29322d32
.word 0x04040004
.word 0x9797972d
.word 0x97979797
.word 0x97979797
.word 0x04979797
.word 0x2d04042e
.word 0x04950428
.word 0x2d972e04
.word 0x042d0404
.word 0x04080804
.word 0x002c0404
.word 0x2c042c04
.word 0x04082895
.word 0x2c2c2c28
.word 0x2d290004
.word 0x2d000800
.word 0x04042d00
.word 0x0804002c
.word 0x00040000
.word 0x04040004
.word 0x05962804
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x97379797
.word 0x92979797
.word 0x29042991
.word 0x2d292d2d
.word 0x9131912d
.word 0x91319191
.word 0x91313191
.word 0x91919191
.word 0x04000491
.word 0x00000029
.word 0x9696962d
.word 0x25323225
.word 0x042e2e2d
.word 0xba2e2e2e
.word 0x29bababa
.word 0x29292d32
.word 0x00002900
.word 0x97972ebf
.word 0x97979797
.word 0x97979797
.word 0x97299797
.word 0x04080404
.word 0x0e082c32
.word 0x08040091
.word 0x00040400
.word 0x042c302c
.word 0x28042804
.word 0x30042c04
.word 0x0808082c
.word 0x28302c08
.word 0x00299128
.word 0x282c2e2c
.word 0x95040000
.word 0x32080404
.word 0x00000000
.word 0x2c000800
.word 0x319b3100
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x97379797
.word 0x92979797
.word 0x00002d91
.word 0x91912d31
.word 0x31319191
.word 0x91912d91
.word 0x2d919191
.word 0x00292d31
.word 0x04000400
.word 0x00000004
.word 0x9696962d
.word 0x9632328e
.word 0x052e2e2e
.word 0xba2e2e2e
.word 0x8dbababa
.word 0x962d2d92
.word 0x04292d29
.word 0x9797bfbf
.word 0x97979797
.word 0x97979797
.word 0x2e2c9697
.word 0x04040904
.word 0x04900804
.word 0x2d910804
.word 0x04280404
.word 0x082c0428
.word 0x31990804
.word 0x952c2c2c
.word 0x28042828
.word 0x2d280408
.word 0x04290404
.word 0x0804002c
.word 0x08043100
.word 0x29080091
.word 0x04280404
.word 0x04040400
.word 0x042c2d04
.word 0x97979708
.word 0x97979797
.word 0x37979797
.word 0x97979797
.word 0x05979797
.word 0x00002d91
.word 0x9191912d
.word 0x312d9191
.word 0x2d913131
.word 0x2d91312d
.word 0x00312d04
.word 0x04002929
.word 0x00000000
.word 0x9696922d
.word 0x923232bf
.word 0x042e322e
.word 0xba2e2e2e
.word 0xbabababa
.word 0x312d2d92
.word 0x298e9696
.word 0x97bfbfbf
.word 0x97979797
.word 0x97979797
.word 0x31289b97
.word 0x05972d08
.word 0x2c040432
.word 0x28082804
.word 0x28280428
.word 0x00040404
.word 0x042c0400
.word 0x28040428
.word 0x04040408
.word 0x00002d00
.word 0x28042804
.word 0x95282d2c
.word 0x042c0400
.word 0x00000404
.word 0x08040000
.word 0x04000000
.word 0x04049991
.word 0x97979704
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x09979797
.word 0x2d002991
.word 0x9191912d
.word 0x318d9131
.word 0x91319131
.word 0x00042d31
.word 0x2891312d
.word 0x00002929
.word 0x00000004
.word 0x9696922d
.word 0x2d3232bf
.word 0x042e3232
.word 0xba2e2e2e
.word 0xbabababa
.word 0x04042992
.word 0xbababa2d
.word 0xbfbfbfbf
.word 0x97979797
.word 0x97979797
.word 0x08049733
.word 0x322d9705
.word 0x2c2e042d
.word 0x2c910804
.word 0x2c280428
.word 0x002c0404
.word 0x00040400
.word 0x0804042c
.word 0x04043004
.word 0x2804082c
.word 0x28000404
.word 0x2c080008
.word 0x002d3104
.word 0x00912804
.word 0x28002900
.word 0x95000004
.word 0x2828082c
.word 0x97979b2d
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9b979797
.word 0x2d052d8d
.word 0x91913131
.word 0x312d9131
.word 0x2d31312d
.word 0x2900042d
.word 0x2d312d91
.word 0x04002929
.word 0x00000004
.word 0x9696922d
.word 0x2e3232bf
.word 0x042e322d
.word 0xba2e2d2e
.word 0x96ba96b6
.word 0xbababab6
.word 0xbabababa
.word 0xbfbfbfbf
.word 0x979797bf
.word 0x97089797
.word 0x2d04970d
.word 0x0000052e
.word 0x00923209
.word 0x28002c2c
.word 0x04043104
.word 0x28910800
.word 0x00040404
.word 0x2d040495
.word 0x0404912c
.word 0x00042895
.word 0x30049600
.word 0x0829302c
.word 0x952c2c04
.word 0x002c0808
.word 0x28000004
.word 0x04000404
.word 0x04293128
.word 0x9797082c
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x312d2d2d
.word 0x912d918d
.word 0x2d319131
.word 0x04912d91
.word 0x29290400
.word 0x2d312d2d
.word 0x00002929
.word 0x00000009
.word 0x9696922d
.word 0x323232bf
.word 0x04963296
.word 0xba2d0404
.word 0xbababab6
.word 0xbabababa
.word 0xbabababa
.word 0xbbbfbf8e
.word 0x979797bf
.word 0x2d329797
.word 0x04339797
.word 0x320a3737
.word 0x04320892
.word 0x2d040428
.word 0x00080036
.word 0x2c080404
.word 0x00000404
.word 0x00992c04
.word 0x95002c04
.word 0x2c2c0830
.word 0x2c282900
.word 0x082c2c00
.word 0x04040804
.word 0x30003004
.word 0x04000008
.word 0x00080408
.word 0x04000800
.word 0x979b0995
.word 0x979b979b
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x31912d2d
.word 0x31319191
.word 0x3131912d
.word 0x0000042d
.word 0x04042d04
.word 0x2d912d2d
.word 0x00002929
.word 0x00000000
.word 0x9691922d
.word 0x2d9632bf
.word 0x912d0404
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbfbf92bb
.word 0x97979bbf
.word 0x97299797
.word 0x0537372e
.word 0x97973796
.word 0x2c280497
.word 0x28282804
.word 0x04280408
.word 0x04000004
.word 0x04000404
.word 0x30080808
.word 0xb904282c
.word 0x28950408
.word 0x282c0028
.word 0x08280491
.word 0x0004002c
.word 0x0008312c
.word 0x08000031
.word 0x9191002d
.word 0x082d0804
.word 0x9b979736
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x9191312d
.word 0x2d319191
.word 0x292d318d
.word 0x2929002d
.word 0x04042900
.word 0x2d312d2d
.word 0x04002909
.word 0x00000004
.word 0x96969131
.word 0x2d290496
.word 0xb6b6ba96
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbf92bb04
.word 0x97979bbf
.word 0x2d379797
.word 0x3797092e
.word 0x29379b97
.word 0x28080497
.word 0x9030042e
.word 0x2c2c082c
.word 0x04040804
.word 0x04000000
.word 0x04000804
.word 0x08312c04
.word 0x2c302c04
.word 0x2c08042c
.word 0x0491302c
.word 0x91040400
.word 0x2c31042c
.word 0x04000491
.word 0x2c30042c
.word 0x282c2828
.word 0x97972d97
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x97979797
.word 0x91312d2d
.word 0x8d91912d
.word 0x2d298d2d
.word 0x2d2d0031
.word 0x04040409
.word 0x8d2d2d2d
.word 0x04002929
.word 0x00000000
.word 0x9696242d
.word 0xbab69691
.word 0xbabababa
.word 0xb6bababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbb9604bb
.word 0x979797bf
.word 0x2e329197
.word 0x0932322e
.word 0x04320409
.word 0x2c280404
.word 0x0424042c
.word 0x2c280428
.word 0x08040490
.word 0x31080404
.word 0x04953100
.word 0x082d9528
.word 0x2c040428
.word 0x2c042804
.word 0x04040491
.word 0x08042c04
.word 0x312c0000
.word 0x0495002d
.word 0x28950400
.word 0x30282808
.word 0x97042c96
.word 0x97979797
.word 0x97979b97
.word 0x97979797
.word 0x97979797
.word 0x91919191
.word 0x2d31912d
.word 0x2d29048d
.word 0x092d002d
.word 0x04290404
.word 0x8d31912d
.word 0x00002929
.word 0x00040004
.word 0x96962d2d
.word 0xbab6b696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x922dbbbb
.word 0x9b979bbf
.word 0x2e2e2897
.word 0x33370931
.word 0x329b972e
.word 0x00040408
.word 0x29043004
.word 0x04040408
.word 0x002c2c04
.word 0x2c040428
.word 0x082c0004
.word 0x28009104
.word 0x90080404
.word 0x08080404
.word 0x0808042c
.word 0x97000800
.word 0x95040000
.word 0x04040828
.word 0x082c9104
.word 0x30282c31
.word 0x97280408
.word 0x97979797
.word 0x97979797
.word 0x97979b97
.word 0x97979797
.word 0x8d913191
.word 0x282d2d2d
.word 0x2d910400
.word 0x0029042d
.word 0x04920404
.word 0x92312d2d
.word 0x2d000429
.word 0x008d2d04
.word 0x96912d2d
.word 0xb6b6b696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x92bbbbbb
.word 0x979b9b2e
.word 0x2d979796
.word 0x04319092
.word 0x979b2e08
.word 0x042d0408
.word 0x2c04082c
.word 0x00042c28
.word 0x0428282d
.word 0x00042804
.word 0x30049904
.word 0x0428082c
.word 0x04280408
.word 0x30089100
.word 0x04040400
.word 0x2d009904
.word 0x32312d00
.word 0x9104302d
.word 0x912c0400
.word 0x04009100
.word 0x97962d28
.word 0x97979797
.word 0x9797979b
.word 0x97979797
.word 0x97979797
.word 0x91919191
.word 0x0004312d
.word 0x2d2d0032
.word 0x04042d2d
.word 0x04092904
.word 0xbf2d2d2d
.word 0x2d2d0029
.word 0x00922d2d
.word 0x96282d2d
.word 0xbab6b696
.word 0xbabababa
.word 0xbababab6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x97bbbbbb
.word 0x9b9b9bbb
.word 0x2e2c9508
.word 0x9604312c
.word 0x3297972e
.word 0x2d040408
.word 0x04950429
.word 0x0000082c
.word 0x042c3029
.word 0x2d910400
.word 0x08000000
.word 0x09912904
.word 0x95902c08
.word 0x04002800
.word 0x08080428
.word 0x04000000
.word 0x00280000
.word 0x0004082c
.word 0x08310400
.word 0x082c0804
.word 0x970d2c2c
.word 0x97979797
.word 0x979b9b97
.word 0x979b979b
.word 0x97979797
.word 0x2d2d8d8d
.word 0x92002d2d
.word 0x2d2d0029
.word 0x04042d2d
.word 0x00002d04
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x00929231
.word 0xb6042d2d
.word 0xb6b6b696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbbbbbbbb
.word 0x9b9b9b9b
.word 0x292e3030
.word 0x97093209
.word 0x2d04059b
.word 0x05092d04
.word 0x28280804
.word 0x91040004
.word 0x08310404
.word 0x00000004
.word 0x00000004
.word 0x08000800
.word 0x28080808
.word 0x04900400
.word 0x04080000
.word 0x00000004
.word 0x042c0828
.word 0x95282c00
.word 0x0004312d
.word 0x042c0431
.word 0x0431952d
.word 0x979b9b96
.word 0x97979b97
.word 0x979b9b97
.word 0x9b9b9797
.word 0x2d2d9191
.word 0x2d2d2d2d
.word 0x2d2d0031
.word 0x04042d2d
.word 0x29000804
.word 0x2d2d2d29
.word 0x312d2d2d
.word 0x00929291
.word 0x96282d31
.word 0xba969696
.word 0xbababab6
.word 0xb6bababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbbbbbbbb
.word 0x2d9b9bbb
.word 0x2c2c2996
.word 0x31322e04
.word 0x082e2d2d
.word 0x04000804
.word 0x28080804
.word 0x042c0804
.word 0x2c043104
.word 0x04080000
.word 0x0400002c
.word 0x04000428
.word 0x28289190
.word 0x2c040408
.word 0x91280000
.word 0x0000002d
.word 0x002c0531
.word 0x28950004
.word 0x04042d95
.word 0x2d2d0404
.word 0x04910828
.word 0x979b9b9b
.word 0x9b9b9797
.word 0x979b9b97
.word 0x9b9b979b
.word 0x042d8d91
.word 0x29322d2d
.word 0x2d2d042d
.word 0x04042d2d
.word 0x2d000904
.word 0x2d2d2d2d
.word 0x912d312d
.word 0x00929191
.word 0x96042d31
.word 0xba96b696
.word 0xbababab6
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbb97bbbf
.word 0x2c9b9bbb
.word 0x31292d04
.word 0x0433282c
.word 0x2d050808
.word 0x0032902c
.word 0x0428082d
.word 0x04080000
.word 0x00040028
.word 0x00000404
.word 0x04000804
.word 0x2c2c912c
.word 0x94040428
.word 0x912e0408
.word 0x08000004
.word 0x04000404
.word 0x04040008
.word 0x0404ba28
.word 0x2d002804
.word 0x049b2e04
.word 0x332d042d
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9797
.word 0x9b97979b
.word 0x00912d91
.word 0x2d042d2d
.word 0x2d290429
.word 0x04042d2d
.word 0x2d2d2900
.word 0x2d2d2d2d
.word 0x91912d2d
.word 0x00929191
.word 0x96042d04
.word 0xb6969696
.word 0xbabababa
.word 0xb6bababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbbbbbfbf
.word 0x9b9b9bbb
.word 0x0497052e
.word 0x28290496
.word 0x97292804
.word 0x042c0891
.word 0x90040400
.word 0x04000404
.word 0x00000404
.word 0x00000000
.word 0x28000095
.word 0x00282800
.word 0x0400952c
.word 0x00002808
.word 0x00280428
.word 0x04912c2d
.word 0x00040804
.word 0x00910804
.word 0x00040004
.word 0x04973704
.word 0x9b040996
.word 0x9b9b9b9b
.word 0x979b9b9b
.word 0x979b9b9b
.word 0x9b9b979b
.word 0x04048d31
.word 0x2d002d2d
.word 0x2d290409
.word 0x2d002d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x00929191
.word 0x96042d00
.word 0xb696b696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0x0496baba
.word 0xbbbfbfbf
.word 0x9b9b9bbb
.word 0x2c9b9b9b
.word 0x2c04042d
.word 0x099b972c
.word 0x00040808
.word 0x04040000
.word 0x08040404
.word 0x31042800
.word 0x04040429
.word 0x04080404
.word 0x04282c04
.word 0x9108042c
.word 0x2c04042c
.word 0x04040004
.word 0x08042828
.word 0x31280028
.word 0x00280000
.word 0x00040000
.word 0x2d040404
.word 0x97050495
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x2e000491
.word 0x2d008d2d
.word 0x2d08052d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x912d312d
.word 0x00929192
.word 0x96002d00
.word 0xb6969696
.word 0xbabababa
.word 0xbabababa
.word 0xb6b6b6ba
.word 0x002424b6
.word 0x00000000
.word 0xbfbfbfbf
.word 0x969b9bbb
.word 0x2d973232
.word 0x96083737
.word 0x32040404
.word 0x04040404
.word 0x2c042904
.word 0x002c0404
.word 0x282c042d
.word 0x04040004
.word 0x00040004
.word 0x04043004
.word 0x08952c04
.word 0x04280404
.word 0x00290028
.word 0x04910431
.word 0x00040000
.word 0x00040028
.word 0x04080000
.word 0x04042d00
.word 0x972e0404
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x2e04282d
.word 0x2d002d2d
.word 0x2d922d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9131312d
.word 0x00929191
.word 0x96002d04
.word 0xb6969696
.word 0xbabababa
.word 0x91babab6
.word 0xba962d28
.word 0x292e0904
.word 0x00040000
.word 0xbfbfbfbf
.word 0x099b9bbf
.word 0x2e973797
.word 0x04973233
.word 0x05290400
.word 0x2d2c0404
.word 0x00040408
.word 0x00040404
.word 0x08040000
.word 0x95043095
.word 0x04042404
.word 0x2c040828
.word 0x0004042c
.word 0x2d2c0028
.word 0x00083000
.word 0x04312c04
.word 0x00000004
.word 0x00000000
.word 0x2d313100
.word 0x002d0800
.word 0x2d2d3232
.word 0x9b9b2d9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x2e042d00
.word 0x2d002d2d
.word 0x2d2d002d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x91312d2d
.word 0x00929191
.word 0x968d2d00
.word 0xb6b69696
.word 0x24babab6
.word 0x00000004
.word 0xbababa96
.word 0x04292d04
.word 0x00292929
.word 0xbfbfbfbf
.word 0x9b9b9bbf
.word 0x9b093732
.word 0x2808979b
.word 0x30080437
.word 0x2c300404
.word 0x00040004
.word 0x00000404
.word 0x00040400
.word 0x28042804
.word 0x2c2c2c08
.word 0x28082800
.word 0x94910404
.word 0x04080495
.word 0x2c2c2800
.word 0x0404042c
.word 0x0004042c
.word 0x00040000
.word 0x04959100
.word 0x04040408
.word 0x2d2c0497
.word 0xbbbbbb2d
.word 0x9bbbbb9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x2e042d04
.word 0x2d002d2d
.word 0x2d2d2d04
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x91912d2d
.word 0x00929191
.word 0x96922d00
.word 0x24b69696
.word 0x00000004
.word 0x00000004
.word 0xbabababa
.word 0x00093224
.word 0x292d292d
.word 0xbfbfbf29
.word 0x9b9b9bbf
.word 0x2e333337
.word 0x08300997
.word 0x04280404
.word 0x04049704
.word 0x00090408
.word 0x00000404
.word 0x31040408
.word 0x04002c28
.word 0x28042800
.word 0x31040428
.word 0x2c300408
.word 0x2c040491
.word 0x30000800
.word 0x9030082c
.word 0x0000042c
.word 0x95040000
.word 0x28040004
.word 0x00080004
.word 0x28009b2d
.word 0xbbbb9bbf
.word 0xbbbbbbbb
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x2e049104
.word 0x2d042d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x91912d2d
.word 0x00929191
.word 0x04912d00
.word 0x0909002d
.word 0x00000404
.word 0x00000000
.word 0xbabab6ba
.word 0x2d2d2d8d
.word 0x2e2d2d29
.word 0xbfbf29bb
.word 0x9b9b9bbf
.word 0x2e2e9b9b
.word 0x0405099b
.word 0x00042808
.word 0x09322904
.word 0x97049708
.word 0x2c000404
.word 0x28040428
.word 0x2d283090
.word 0x28280090
.word 0x0404002c
.word 0x04040404
.word 0x2c280430
.word 0x002d0408
.word 0x04000430
.word 0x2c040400
.word 0x91000804
.word 0x91042800
.word 0x042c0828
.word 0x08920000
.word 0xbbbb2997
.word 0xbbbbbbbb
.word 0x9b9b9bbb
.word 0x9b9b9b9b
.word 0x2e049104
.word 0x2d2d292d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d912d2d
.word 0x00929191
.word 0x2d2d2d00
.word 0x2d2d0031
.word 0x00000992
.word 0x00000000
.word 0xbababab6
.word 0x2d3232ba
.word 0x292d2d04
.word 0xbb2dbb96
.word 0x9b9b9bbf
.word 0x322e3397
.word 0x97293297
.word 0x04910031
.word 0x00000008
.word 0x0400042e
.word 0x04000400
.word 0x04043004
.word 0x04280404
.word 0x04280808
.word 0x3104002c
.word 0x2c04962c
.word 0x0404002d
.word 0x08009504
.word 0x08002c2c
.word 0x04000030
.word 0x00002d00
.word 0x04042c04
.word 0x2c2c2895
.word 0x96959b09
.word 0xbbbb2d2d
.word 0xbbbbbbbb
.word 0x9bbbbbbb
.word 0x9b9b9b9b
.word 0x2e042d24
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9131312d
.word 0x0000048d
.word 0x96922d00
.word 0x2e2d0096
.word 0x04000432
.word 0x00000000
.word 0xbabab6b6
.word 0x2d9292ba
.word 0x292d2d08
.word 0x31bbbbbb
.word 0x9b9b9bbb
.word 0x9b979b9b
.word 0x9b042d32
.word 0x28040097
.word 0x04090404
.word 0x04049737
.word 0x04040000
.word 0x95080404
.word 0x00040408
.word 0x2d282c95
.word 0x0404082c
.word 0x04040004
.word 0x2c040095
.word 0x95000828
.word 0x08000495
.word 0x00000004
.word 0x04000004
.word 0x2c280408
.word 0x2c90302c
.word 0x04910491
.word 0xbbbb9700
.word 0xbbbbbbbb
.word 0xbbbbbbbb
.word 0x2e9bbb9b
.word 0x04299128
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x0004912d
.word 0x00000000
.word 0x96929100
.word 0x322d2996
.word 0x3104002e
.word 0x00000004
.word 0xbababab6
.word 0x299292ba
.word 0x2d2d2d04
.word 0xbbbf9bbb
.word 0x9b9b9b97
.word 0x9b9b9b9b
.word 0x2d2a049b
.word 0x04009b04
.word 0x04280404
.word 0x2d299b00
.word 0x04000400
.word 0x042c0404
.word 0x04280804
.word 0x282c2c04
.word 0x0428042d
.word 0x04040428
.word 0x91042c28
.word 0x2c082800
.word 0x04950404
.word 0x00000004
.word 0x00040000
.word 0x312c2c04
.word 0x2d280895
.word 0x2c9a2c2c
.word 0xbbbbbb2d
.word 0xbbbbbbbb
.word 0xbbbbbbbb
.word 0x00bbbbbb
.word 0x2d092d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x282d2d2d
.word 0x00000000
.word 0x00000000
.word 0x91923100
.word 0x322eb696
.word 0x08040032
.word 0x00000004
.word 0xbabab6b6
.word 0x2d9296ba
.word 0x2d2d2d04
.word 0xbbbb9bbb
.word 0x9b9b9b97
.word 0x9b9b3332
.word 0x00090497
.word 0x04043731
.word 0x00040400
.word 0x00009704
.word 0x04040800
.word 0x00042c04
.word 0x04042c95
.word 0x04002d30
.word 0x28040000
.word 0x28040400
.word 0x04000830
.word 0x2c082804
.word 0x0004002c
.word 0x00000000
.word 0x04000000
.word 0x95280404
.word 0x912c2804
.word 0x28082804
.word 0x9b9b9b04
.word 0xbb9b9b9b
.word 0xbbbbbbbb
.word 0x04bbbbbb
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d04
.word 0x00000004
.word 0x00000000
.word 0x91922d00
.word 0x3232bf96
.word 0x04040032
.word 0x00000000
.word 0xbab6bab6
.word 0xbf969bba
.word 0x2d2e2d04
.word 0xbbbbbbbb
.word 0x9b9b9b9b
.word 0x9b9b3797
.word 0x04043032
.word 0x049b0008
.word 0x04080504
.word 0x04000008
.word 0x04000400
.word 0x042d0400
.word 0x2c082804
.word 0x2c000004
.word 0x04290492
.word 0x04000000
.word 0x312c2828
.word 0x04080095
.word 0x00000890
.word 0x042c0404
.word 0x00000408
.word 0x2c040400
.word 0x04950408
.word 0x08282895
.word 0x9b9b9b09
.word 0x9b9b9b9b
.word 0xbbbbbb9b
.word 0x0496bbbb
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x00042d2d
.word 0x2d2d2d04
.word 0x00000029
.word 0x00000400
.word 0x91922d00
.word 0x3232bf96
.word 0x04090432
.word 0x00000000
.word 0xbab6bab6
.word 0x9b9696ba
.word 0x2d2d2d04
.word 0xbbbb9bbb
.word 0x9b9b9b9b
.word 0x9b2d9b37
.word 0x28040809
.word 0x32040404
.word 0x04089b04
.word 0x04950004
.word 0x00280000
.word 0x00080000
.word 0x28280404
.word 0x282c0431
.word 0x08282900
.word 0x00040008
.word 0x00040408
.word 0x2c040408
.word 0x96090404
.word 0x042c3228
.word 0x00040028
.word 0x04910404
.word 0x04049500
.word 0x2c28912c
.word 0x9b9b9b31
.word 0x9b9b9b9b
.word 0xbb9b9b9b
.word 0x25bb92bb
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x00000004
.word 0x2d2d2d00
.word 0x00000029
.word 0x00000000
.word 0x91920000
.word 0x3232bf96
.word 0x00090492
.word 0x00000000
.word 0xbab6bab6
.word 0x969696ba
.word 0x0429b704
.word 0xbbbb97bb
.word 0x9b9b9b9b
.word 0x2c319b97
.word 0x2c240409
.word 0x04090404
.word 0x00000400
.word 0x00080000
.word 0x04040404
.word 0x04040404
.word 0x08082808
.word 0x082c0804
.word 0x00002831
.word 0x00310004
.word 0x00319104
.word 0x28300408
.word 0x002d0404
.word 0x2d080028
.word 0x2c080428
.word 0x002d0404
.word 0x04000000
.word 0x2c282808
.word 0x9b9b9b2c
.word 0x9b9b9b9b
.word 0x2e9b9b9b
.word 0x249b9b9b
.word 0x2d2d2d00
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x00002d2d
.word 0x00042d00
.word 0x2d2d2d00
.word 0x0000042d
.word 0x00000000
.word 0x91920000
.word 0x92329696
.word 0x00292992
.word 0x00000000
.word 0xbab6baba
.word 0x290404b6
.word 0xbababa29
.word 0xbbbb92bf
.word 0x379b9b9b
.word 0x912d2837
.word 0x9131042c
.word 0x32320091
.word 0x04280400
.word 0x002c3090
.word 0x282c2d04
.word 0x00040404
.word 0x04080004
.word 0x2c040404
.word 0x04282828
.word 0x28042800
.word 0x97082d99
.word 0x2c042800
.word 0x00000404
.word 0x08002c2d
.word 0x04009100
.word 0x00009104
.word 0x04280408
.word 0x04919a2c
.word 0x9b9b929b
.word 0x9b9b9b9b
.word 0x9b9b979b
.word 0x242e9b9b
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x29002d29
.word 0x04280400
.word 0x2d2d2d00
.word 0x0000002d
.word 0x04000000
.word 0x91920000
.word 0x92329696
.word 0x00290492
.word 0x04049600
.word 0xbab6b696
.word 0xbabababa
.word 0xbabababa
.word 0xbbbfbfbf
.word 0x9b9b9b9b
.word 0x92329b9b
.word 0x962c0428
.word 0x04042e30
.word 0x2c280800
.word 0x00040404
.word 0x2c040028
.word 0x00282c08
.word 0x08280000
.word 0x04080408
.word 0x00280095
.word 0x31002800
.word 0x292c0804
.word 0x2d280428
.word 0x04000404
.word 0x08292c00
.word 0x30950831
.word 0x00000495
.word 0x04290004
.word 0x2c302828
.word 0x9b9b082c
.word 0x329b9b9b
.word 0x9b9b9b9b
.word 0x249b9b9b
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d042d2d
.word 0x2d002d2d
.word 0x04000000
.word 0x2d2d2d00
.word 0x0000002d
.word 0x04040000
.word 0x92910000
.word 0x96329696
.word 0x0404042d
.word 0x96962d29
.word 0xbabab696
.word 0xbabababa
.word 0xbabababa
.word 0xbfbfbfbf
.word 0x969b969b
.word 0x2d97329b
.word 0x972d2c29
.word 0x00002d00
.word 0x08040000
.word 0x00040404
.word 0x2c000004
.word 0x0004082c
.word 0x04082808
.word 0x04040400
.word 0x04280004
.word 0x04080404
.word 0x2c2c0404
.word 0x91992c00
.word 0x0400042d
.word 0x042d0808
.word 0x28282c00
.word 0x00000804
.word 0x04002831
.word 0x2c082831
.word 0x9b9b2e08
.word 0x9b9b979b
.word 0x9bbbbbbb
.word 0x249b9b9b
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d04042d
.word 0x2d002d2d
.word 0x04040004
.word 0x2d2d2d29
.word 0x0000002d
.word 0x002d0000
.word 0x2d960000
.word 0x04049696
.word 0x96962d29
.word 0xb6969696
.word 0xbabab6ba
.word 0xbabababa
.word 0xbabababa
.word 0xbfbfbfbf
.word 0x2d3296bf
.word 0x28283696
.word 0x97052896
.word 0x009b9732
.word 0x04930004
.word 0x90000428
.word 0x04000428
.word 0x00280408
.word 0x04042c04
.word 0x282c3004
.word 0x298d0028
.word 0x08280000
.word 0x2c2c2c04
.word 0x042c2c91
.word 0x00313104
.word 0x04313004
.word 0x28280404
.word 0x04002804
.word 0x00000808
.word 0x0428082d
.word 0x9b9b2804
.word 0x9b9b9b9b
.word 0x9bbb9b9b
.word 0x249b9b9b
.word 0x2d2d2d2d
.word 0x042d2d2d
.word 0x2d2d0000
.word 0x2d002d2d
.word 0x0429002d
.word 0x2d2d2d2d
.word 0x2d00002d
.word 0x00090004
.word 0x042d0000
.word 0x96962d96
.word 0x96969696
.word 0xbab6b696
.word 0xbabababa
.word 0xbabababa
.word 0xbabababa
.word 0xbfbfbfbf
.word 0x082c08bf
.word 0x2d2e3230
.word 0x972d9608
.word 0x04049b2e
.word 0x04040000
.word 0x28040490
.word 0x0404002c
.word 0x2c2c0404
.word 0x902c9500
.word 0x0004292c
.word 0x002d0404
.word 0x95000028
.word 0x91289000
.word 0x28959104
.word 0x00083108
.word 0x002c9504
.word 0x0008302d
.word 0x2c040004
.word 0x04042c28
.word 0x00950495
.word 0x979b952c
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x249b9b9b
.word 0x2d2d2d2d
.word 0x04042d2d
.word 0x2d920004
.word 0x2d002d2d
.word 0x29002d2d
.word 0x2d2d2d04
.word 0x2d04002d
.word 0x00000404
.word 0x042d0000
.word 0x96969696
.word 0x96969696
.word 0xb6b6b696
.word 0xbababab6
.word 0xbabababa
.word 0xbabababa
.word 0xbfbfbf92
.word 0x953632bf
.word 0x302c2d2d
.word 0x97049797
.word 0x3204049b
.word 0x042c0404
.word 0x04282c04
.word 0x08002c04
.word 0x08040000
.word 0x04282c04
.word 0x00089008
.word 0x0408042d
.word 0x28000004
.word 0x9a000404
.word 0x002c0400
.word 0x0800282d
.word 0x00302d00
.word 0x00000000
.word 0x2c310400
.word 0x00003108
.word 0x00000000
.word 0x9b9b309b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x249b9b9b
.word 0x2d2d2d2d
.word 0x04282d2d
.word 0x2d090004
.word 0x00002d2d
.word 0x2d000400
.word 0x2d2d2d00
.word 0x002929ba
.word 0x2d2d2d04
.word 0x042d0000
.word 0x96969696
.word 0x96969696
.word 0xb6b69696
.word 0xbabab6ba
.word 0xbabababa
.word 0xbabababa
.word 0xbfbf259b
.word 0x2d2e2dbf
.word 0x94292e96
.word 0x04312d2d
.word 0x32052e9b
.word 0x00329b33
.word 0x00040431
.word 0x04040404
.word 0x04080400
.word 0x04040404
.word 0x04049604
.word 0x00042804
.word 0x04000004
.word 0x2c2c009a
.word 0x04049508
.word 0x00280004
.word 0x282d0008
.word 0x00040091
.word 0x04000404
.word 0x04002804
.word 0x042d0000
.word 0x9b9b3104
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x249b9b9b
.word 0x282d2d2d
.word 0x04292d00
.word 0x91000029
.word 0x00002d2d
.word 0x04040400
.word 0x2d2d2d00
.word 0x2d2d2900
.word 0x912d2d2d
.word 0x002d0000
.word 0x96969692
.word 0x96969696
.word 0xb6b69696
.word 0xb6babab6
.word 0xbabababa
.word 0xbabababa
.word 0xbf29bb96
.word 0x929709bf
.word 0x32972d31
.word 0x309b092d
.word 0x099b2e05
.word 0x0496099b
.word 0x00082828
.word 0x04040404
.word 0x04000404
.word 0x04082d04
.word 0x95049530
.word 0x00000404
.word 0x28000000
.word 0x08080404
.word 0x04000008
.word 0x00000800
.word 0x2c912c08
.word 0x04009508
.word 0x30002800
.word 0x04280808
.word 0x04043192
.word 0xbbbbbb04
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x249b9b9b
.word 0x002d2d2d
.word 0x04292d04
.word 0x92000492
.word 0x05042d2d
.word 0x00040000
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x91912d2d
.word 0x042d0000
.word 0x96969696
.word 0x96969696
.word 0xb696b6b6
.word 0xbababab6
.word 0xbabababa
.word 0xbabababa
.word 0x29bb04bb
.word 0x952c0991
.word 0x2832292e
.word 0x969b9296
.word 0x2e043332
.word 0x97099b97
.word 0x08040404
.word 0x00040004
.word 0x0028042d
.word 0x00000404
.word 0x31040400
.word 0x2c912c04
.word 0x2c000404
.word 0x91040404
.word 0x04080400
.word 0x952c2c00
.word 0x2c080495
.word 0x00009195
.word 0x00280404
.word 0x04040400
.word 0x322c0932
.word 0x28319b96
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x249b9b9b
.word 0x00042d2d
.word 0x042d2d29
.word 0x96000096
.word 0x042d2d2d
.word 0x29000404
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x002d0000
.word 0x96969692
.word 0x96969696
.word 0xb6b6b696
.word 0xbababab6
.word 0xbabababa
.word 0xbabababa
.word 0xbb929b96
.word 0x3204042c
.word 0x08043204
.word 0x08299b2e
.word 0x37979b2c
.word 0x329b0e9b
.word 0x0004042e
.word 0x08040004
.word 0x04000400
.word 0x29000400
.word 0x04000004
.word 0x00300404
.word 0x29040028
.word 0x24280400
.word 0x08080028
.word 0x0004082c
.word 0x04283108
.word 0x31002804
.word 0x042c0400
.word 0x08040431
.word 0x96289b04
.word 0x9b2d9b04
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x049b9b9b
.word 0x00042d2d
.word 0x042d2d2e
.word 0x2d000492
.word 0x2d2d2d2d
.word 0x2d2d2900
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x91919191
.word 0x002d0000
.word 0x96969696
.word 0x96969696
.word 0xb696b696
.word 0xbababab6
.word 0xbabababa
.word 0xbabababa
.word 0xbbbbbb96
.word 0x9b972d04
.word 0x9732099b
.word 0x00329b33
.word 0x2d979b9b
.word 0x9b36929b
.word 0x04003228
.word 0x28000000
.word 0x04040430
.word 0x00080400
.word 0x00040028
.word 0x04042c2d
.word 0x00280400
.word 0x31280400
.word 0x2d000400
.word 0x082c0428
.word 0x91009528
.word 0x9528002c
.word 0x0404042c
.word 0x00040895
.word 0x95082c28
.word 0x9b9b9b09
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x249b9b32
.word 0x04282d04
.word 0x042d2d32
.word 0x29000429
.word 0x2d042d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x91919191
.word 0x242d0000
.word 0x96969696
.word 0x96969696
.word 0xb696b696
.word 0xbab6b6b6
.word 0xbabababa
.word 0xbabababa
.word 0xbbbbbb96
.word 0x2a2ebf08
.word 0x9b2e3232
.word 0x082d2d97
.word 0x9b2d2d28
.word 0x302d9b9b
.word 0x00042d08
.word 0x04000404
.word 0x00040400
.word 0x00040028
.word 0x28040404
.word 0x00040432
.word 0x04040000
.word 0x2c043029
.word 0x04040004
.word 0x00280400
.word 0x3104082c
.word 0x042d0400
.word 0x00000004
.word 0x04009a04
.word 0x91049600
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x299b9b9b
.word 0x04290400
.word 0x042d2d32
.word 0x29002d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x91919191
.word 0x912d0000
.word 0x96969692
.word 0x96969696
.word 0xb6b69696
.word 0xbab6b6ba
.word 0xbabababa
.word 0xbabababa
.word 0xbbbbbb96
.word 0x2d2e32bb
.word 0x9b970404
.word 0x099b0432
.word 0x9b9b979b
.word 0x0932082c
.word 0x00040408
.word 0x04040400
.word 0x00040400
.word 0x04040400
.word 0x04000008
.word 0x2d2d0432
.word 0x00000000
.word 0x04040400
.word 0x04040404
.word 0x0000042c
.word 0x91002804
.word 0x04000000
.word 0x2d000000
.word 0x00040004
.word 0x91280500
.word 0x059b9b9b
.word 0x9b9b329b
.word 0x9b9b9b9b
.word 0x009b9b9b
.word 0x04290000
.word 0x052d2d32
.word 0x2d290029
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x92919191
.word 0x912d0000
.word 0x96969691
.word 0x96969696
.word 0xb6b6b6b6
.word 0xb6b6baba
.word 0xbab6b6b6
.word 0x00042492
.word 0xbb969696
.word 0x29042ebb
.word 0x2d9b0031
.word 0x9b9b0408
.word 0x969b9b09
.word 0x082d2c2d
.word 0x04050429
.word 0x04040000
.word 0x00000404
.word 0x00040400
.word 0x04000008
.word 0x04042904
.word 0x08040400
.word 0x04000004
.word 0x00000004
.word 0x00049100
.word 0x04000000
.word 0x00000000
.word 0x00000400
.word 0x04002900
.word 0x08920004
.word 0x9b9b9b96
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x049b9b9b
.word 0x04290400
.word 0x042d2d32
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x91919191
.word 0x912d0000
.word 0x96969692
.word 0x96969696
.word 0xb6969696
.word 0x2d2891b6
.word 0x2400ba2d
.word 0x00000000
.word 0xbbbbbbbf
.word 0x0429299b
.word 0x242c0432
.word 0x0532042d
.word 0x2c9b972d
.word 0x2c040830
.word 0x002e958d
.word 0x00040000
.word 0x00000000
.word 0x2c280400
.word 0x04000408
.word 0x042c282d
.word 0x0000002c
.word 0x04040004
.word 0x00000404
.word 0x2d280400
.word 0x00000028
.word 0x04000004
.word 0x00000000
.word 0x29320000
.word 0x04952d00
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x259b9b9b
.word 0x04292900
.word 0x2d2d2d32
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9291912d
.word 0x912d0004
.word 0x96969291
.word 0x96969696
.word 0x00000424
.word 0xb6bab604
.word 0x0000bab6
.word 0x00000004
.word 0xbb9bbfbf
.word 0x2d2d9b9b
.word 0xb12d2e09
.word 0x32090408
.word 0x049b9708
.word 0x08960804
.word 0x00970004
.word 0x00000000
.word 0x04009b04
.word 0x04040408
.word 0x24040091
.word 0x04040400
.word 0x002c0028
.word 0x04280000
.word 0x00042800
.word 0x282c0831
.word 0x00280004
.word 0x00000000
.word 0x00000000
.word 0x04040000
.word 0x04040004
.word 0x9b9b9b31
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x259b9b9b
.word 0x04292d00
.word 0x2d2d2d32
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x91040004
.word 0x91969192
.word 0x04000024
.word 0x29090004
.word 0xb6b6b609
.word 0x0400baba
.word 0x04040029
.word 0x96bbbfbf
.word 0x97969b9b
.word 0x2c000932
.word 0x04042c04
.word 0x248d2828
.word 0x28288804
.word 0x2828042c
.word 0x89040400
.word 0x002d0024
.word 0x08000028
.word 0x04040004
.word 0x04040428
.word 0x00002d08
.word 0x04000404
.word 0x04040004
.word 0x2c040404
.word 0x91000408
.word 0x00290000
.word 0x00000000
.word 0x00042900
.word 0x28040031
.word 0x9b920928
.word 0x9b9b9b9b
.word 0x9b9b9b9b
.word 0x249b9b9b
.word 0x04292900
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x28000004
.word 0x04242d29
.word 0x292d2929
.word 0x09050029
.word 0xbab6b609
.word 0x0400bab6
.word 0x04040404
.word 0xbfbbbfbf
.word 0x2d049b9b
.word 0x04902830
.word 0x2c082c04
.word 0xad892c88
.word 0x2c24288d
.word 0x95080808
.word 0x00002804
.word 0x04b62400
.word 0x04040004
.word 0x00040004
.word 0x08000029
.word 0x00000004
.word 0x31280400
.word 0x00290005
.word 0x28040000
.word 0x08970830
.word 0x00000000
.word 0x00000000
.word 0x04000028
.word 0x96040404
.word 0xbf92bf2c
.word 0x2ebfbfbf
.word 0x9b9bbbbf
.word 0x049b9b9b
.word 0x2d290000
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x0428918d
.word 0x2d000004
.word 0x29299691
.word 0x292d2929
.word 0x09090029
.word 0xb6b69629
.word 0x0004baba
.word 0x29050404
.word 0xbfbfbfbf
.word 0x2c91099b
.word 0x04042c30
.word 0x00282804
.word 0x048d8d28
.word 0x04280428
.word 0x002c002c
.word 0x00002404
.word 0x04002000
.word 0x2c280804
.word 0x04042804
.word 0x04000031
.word 0x00040031
.word 0x00292904
.word 0x00000000
.word 0x2c910029
.word 0x00042d04
.word 0x00000000
.word 0x04000429
.word 0x08280400
.word 0x042c0804
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbfbfbfbb
.word 0x29bfbfbf
.word 0x2d2d0004
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x04042d2d
.word 0x00040000
.word 0x91000004
.word 0x29b69291
.word 0x29002929
.word 0x29090009
.word 0xb6b6b629
.word 0x0404baba
.word 0x29290004
.word 0xbfbfbfbf
.word 0x30059b9b
.word 0x28089196
.word 0x04040004
.word 0x04042428
.word 0x29040400
.word 0x00002d08
.word 0x00000400
.word 0x00000000
.word 0x042c3100
.word 0x0400042c
.word 0x00000400
.word 0x00000004
.word 0x00000000
.word 0x00000008
.word 0x91910400
.word 0x28319104
.word 0x00000400
.word 0x00000504
.word 0x2c310000
.word 0x91950828
.word 0xbfbfbf96
.word 0xbbbfbfbf
.word 0xbfbfbfbf
.word 0x24bfbfbf
.word 0x2d2d2924
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x282d2d2d
.word 0x0004002d
.word 0x00000000
.word 0x91000000
.word 0x29bf9691
.word 0x09002929
.word 0x29290509
.word 0xb6b6b629
.word 0x0404bab6
.word 0x04040029
.word 0xbfbfbf29
.word 0x04329b9b
.word 0x2808322e
.word 0x08042c28
.word 0x04292400
.word 0x08280804
.word 0x04040400
.word 0x00000000
.word 0x00b68d00
.word 0x04040004
.word 0x2800002c
.word 0x00040000
.word 0x00000400
.word 0x00002d00
.word 0x00000000
.word 0x042c0000
.word 0x042c0800
.word 0x00000000
.word 0x04009b00
.word 0x00040000
.word 0x0491002c
.word 0x92929295
.word 0x92929292
.word 0x91929292
.word 0x242d8d91
.word 0x2d2d2d24
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d0004
.word 0x0000002d
.word 0x00000000
.word 0x91000000
.word 0x29bf9291
.word 0x09002929
.word 0x29292e09
.word 0xb6b69629
.word 0x0404bab6
.word 0x04250404
.word 0xbb2929bb
.word 0x28049b9b
.word 0x28082d04
.word 0x04040428
.word 0x00040404
.word 0x04243004
.word 0x2c04082c
.word 0x04000000
.word 0x00b60400
.word 0x04000000
.word 0x29000030
.word 0x00000000
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x04040432
.word 0x30950800
.word 0x29003108
.word 0x04002900
.word 0x08000000
.word 0x2c049104
.word 0xbfbfbf2c
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0x24bfbfbf
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x0000042d
.word 0x2d2d0000
.word 0x0000042d
.word 0x00000000
.word 0x91000000
.word 0x29969691
.word 0x09042929
.word 0x29092909
.word 0xb6b69629
.word 0x0429b6b6
.word 0x04280004
.word 0x2996bb00
.word 0x2932979b
.word 0x04292d04
.word 0x04000404
.word 0x28000400
.word 0x04002c24
.word 0x04080428
.word 0x00040000
.word 0x0000b528
.word 0x04000004
.word 0x04040004
.word 0x00000004
.word 0x00000400
.word 0x04040000
.word 0x00000004
.word 0x04000400
.word 0x04310400
.word 0x00000004
.word 0x04040400
.word 0x31000004
.word 0x2c040028
.word 0x8925bb2c
.word 0xbfbfbf8d
.word 0x898d89bf
.word 0x24bfbfbf
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x00042d2d
.word 0x00040000
.word 0x2d2d0000
.word 0x0000292d
.word 0x00000000
.word 0x91000000
.word 0x29969291
.word 0x09042929
.word 0x29290929
.word 0xb6b69629
.word 0x0429b6b6
.word 0x04920404
.word 0xbb969bbb
.word 0x329b9733
.word 0x04903190
.word 0x04282804
.word 0x00042429
.word 0x04000404
.word 0x00043128
.word 0x04000400
.word 0x24080000
.word 0x00000000
.word 0x292d0400
.word 0x00000004
.word 0x00000000
.word 0x04000400
.word 0x00000000
.word 0x00290400
.word 0x00000000
.word 0x31310000
.word 0x00003095
.word 0x00043100
.word 0x08000404
.word 0xbfbf9295
.word 0xbfbfbfbf
.word 0xbb9b97bf
.word 0x24bfbfbf
.word 0x2d2d2d8d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x002d2d28
.word 0x00000004
.word 0x2d2d0000
.word 0x0000292d
.word 0x04000000
.word 0x91000000
.word 0x2996912d
.word 0x09040929
.word 0x29922929
.word 0xb6b69629
.word 0x0492b6b6
.word 0x29042904
.word 0x059bbbbb
.word 0x2e97979b
.word 0x2c2c042d
.word 0x04040495
.word 0x08040400
.word 0x042c2c04
.word 0x00040428
.word 0x04000004
.word 0x0004042c
.word 0x04000400
.word 0x24040400
.word 0x00000008
.word 0x9b000000
.word 0x2d000000
.word 0x04040000
.word 0x2d000000
.word 0x00040000
.word 0x3104002d
.word 0x00082800
.word 0x00040004
.word 0x28910808
.word 0xbf280891
.word 0xbfbfbf2d
.word 0xbbbb9bbf
.word 0x24bfbfbf
.word 0x2d2d2d96
.word 0x2d2d2d2d
.word 0x00042d2d
.word 0x042d2d2d
.word 0x00000004
.word 0x2d2d0000
.word 0x00002d2d
.word 0x2d000000
.word 0x91000000
.word 0x09929204
.word 0x29040929
.word 0x292d2929
.word 0xb6b62929
.word 0x962db6b6
.word 0x29042992
.word 0xbbbbbbbb
.word 0x9b9b9b97
.word 0x0424059b
.word 0x04080400
.word 0x00040404
.word 0x08002800
.word 0x2c040400
.word 0x04000008
.word 0x042c2804
.word 0x002c2804
.word 0x29290000
.word 0x00000029
.word 0x00000000
.word 0x00000029
.word 0x00000000
.word 0x28040000
.word 0x00000400
.word 0x04303004
.word 0x28280491
.word 0x08040400
.word 0x08300408
.word 0x95bf282c
.word 0xbfbfbfbf
.word 0x969296bf
.word 0x92bfbfbf
.word 0x2d2d2d96
.word 0x292d2d2d
.word 0x292d0000
.word 0x042d2d29
.word 0x00000004
.word 0x2d2d0000
.word 0x00002d2d
.word 0x08000000
.word 0x91000000
.word 0x29969604
.word 0x29040929
.word 0x29042929
.word 0xb6b6082d
.word 0x08049696
.word 0x9696912d
.word 0xbbbbbbbb
.word 0x9b979b9b
.word 0x0488979b
.word 0x04040400
.word 0x24000000
.word 0x08040004
.word 0x04040404
.word 0x00000004
.word 0x28000004
.word 0x002c0800
.word 0x28002804
.word 0x00000400
.word 0x00000000
.word 0x00000000
.word 0x00000029
.word 0x04290000
.word 0x95040495
.word 0x282c2c2c
.word 0x082c0808
.word 0x00310431
.word 0x042c0000
.word 0x0804282d
.word 0xbfbfbf9a
.word 0xbbbbbbbf
.word 0x29bfbfbf
.word 0x2d2d2d24
.word 0x042d292d
.word 0x24290024
.word 0x002d2d2d
.word 0x00000004
.word 0x2d2d0000
.word 0x04002d2d
.word 0x00000000
.word 0x91000000
.word 0x29969204
.word 0x2d049296
.word 0x04040404
.word 0x96969628
.word 0xb6b696b6
.word 0xb6b6b6b6
.word 0xbbbbbb96
.word 0x9b9b9b9b
.word 0x00899b9b
.word 0x00000404
.word 0x04000000
.word 0x00000400
.word 0x04049100
.word 0x04040004
.word 0x00000000
.word 0x04000404
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00320000
.word 0x2c28042d
.word 0x08042828
.word 0x08082828
.word 0x00040800
.word 0x04000000
.word 0x002d2c04
.word 0xbfbf962c
.word 0xbfbfbfbf
.word 0x29bfbfb6
.word 0x2d2d2d2d
.word 0x282d2d04
.word 0x2d290029
.word 0x042d2d2d
.word 0x00000004
.word 0x2d2d0000
.word 0x00002d2d
.word 0x00000004
.word 0x91000000
.word 0x04969200
.word 0x29280404
.word 0x96969131
.word 0xb6b69696
.word 0xbab6b6b6
.word 0xbabab6b6
.word 0xbb96bbbb
.word 0x9b979b9b
.word 0x8489bb05
.word 0x04040024
.word 0x00000489
.word 0x04002c00
.word 0x04040004
.word 0x08040400
.word 0x28000400
.word 0x00000404
.word 0x00000028
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00040000
.word 0x00082800
.word 0x00042c04
.word 0x00040404
.word 0x00289204
.word 0x00280000
.word 0x04000400
.word 0x95000404
.word 0xbfbfbf04
.word 0xbfbfbfbf
.word 0x9296bf96
.word 0x042d2d00
.word 0x292d0404
.word 0x24240004
.word 0x292d2d29
.word 0x00000008
.word 0x2d2d0004
.word 0x00008d2d
.word 0x2904002d
.word 0x2d000009
.word 0x912d9100
.word 0x96969696
.word 0x96969696
.word 0xb6b69696
.word 0xbababab6
.word 0xbab6bab6
.word 0xbbbbbbbf
.word 0x9bbb8d29
.word 0x88898997
.word 0x00000024
.word 0x282c2424
.word 0x2c040400
.word 0x00080404
.word 0x04000000
.word 0x00240404
.word 0x00000400
.word 0x00000000
.word 0x00040404
.word 0x00000000
.word 0x00000000
.word 0x00000004
.word 0x2d282800
.word 0x04000004
.word 0x00040804
.word 0x04040404
.word 0x00002900
.word 0x04000400
.word 0x04040004
.word 0xbbbbbe2c
.word 0x96bbbfbb
.word 0x92bbbbb6
.word 0x00292904
.word 0x292d0029
.word 0x04310004
.word 0x292d2d29
.word 0x0400002d
.word 0x2d2d0004
.word 0x0429b62d
.word 0x04000029
.word 0x2d000029
.word 0x92929200
.word 0x96969692
.word 0x96969696
.word 0xb6b69696
.word 0xb6babab6
.word 0xbabababa
.word 0x92bfbfbf
.word 0x9bbf912d
.word 0x2889ad9b
.word 0x04000004
.word 0x0404ad8d
.word 0x04040404
.word 0x282c002c
.word 0x04042800
.word 0x00000004
.word 0x00000400
.word 0x00040028
.word 0x00000028
.word 0x00000000
.word 0x00000004
.word 0x00040000
.word 0x95950000
.word 0x2d040804
.word 0x04000400
.word 0x0000000d
.word 0x0000bf04
.word 0x00002800
.word 0x0091002d
.word 0xba92282c
.word 0xbbbbbbbb
.word 0x24b6bbbb
.word 0x002d0404
.word 0x292d292d
.word 0x00290404
.word 0x042d2d2d
.word 0x0400002d
.word 0x2d2d0004
.word 0x2900242d
.word 0x2d2d2d29
.word 0x2d00002d
.word 0x96969200
.word 0x96969696
.word 0xb6b69696
.word 0xb6b69696
.word 0xb6b6bab6
.word 0xbabab6ba
.word 0xbfbfbfbf
.word 0x972d2808
.word 0x248d889b
.word 0x88042404
.word 0x95048d8d
.word 0x00000404
.word 0x08000028
.word 0x04040000
.word 0x00000000
.word 0x00280000
.word 0x00000029
.word 0x00000092
.word 0x00000000
.word 0x00002900
.word 0x00000400
.word 0x31000000
.word 0x042d9199
.word 0x00000004
.word 0x2c000092
.word 0x04290000
.word 0x04040000
.word 0x04042d08
.word 0x29282c04
.word 0x29282829
.word 0x29292929
.word 0x002d0024
.word 0x292d2d04
.word 0x042d0004
.word 0x002d2d2d
.word 0x2929002d
.word 0x2d2d0029
.word 0x2d2d2d2d
.word 0x912d2d2d
.word 0x2d000091
.word 0x96919100
.word 0x96969696
.word 0xb6969696
.word 0xb6b6b6b6
.word 0xb6bab6b6
.word 0xbab6baba
.word 0xbfbfbfbf
.word 0x922d2d2c
.word 0xad04ad32
.word 0xad8888b1
.word 0x9a00888d
.word 0x04042c95
.word 0x04040400
.word 0x04000000
.word 0x00000004
.word 0x00000428
.word 0x00040004
.word 0x00040400
.word 0x00000000
.word 0x04000000
.word 0x04040000
.word 0x2d00002d
.word 0x00082900
.word 0x2d042d00
.word 0x00082d04
.word 0x04000400
.word 0x00000404
.word 0x2800042c
.word 0x9231312c
.word 0x04042492
.word 0x24919291
.word 0x002d0424
.word 0x292d0400
.word 0x2d040008
.word 0x002d2d2d
.word 0x04000004
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x91912d2d
.word 0x04000091
.word 0x92929228
.word 0x96969696
.word 0xb6969696
.word 0xb69696b6
.word 0xb6bab6b6
.word 0xbabab6ba
.word 0xbfbfbfbf
.word 0x2d282c04
.word 0xad8dad2d
.word 0xad84888d
.word 0x04008d88
.word 0x28080004
.word 0x31040004
.word 0x00040004
.word 0x00000000
.word 0x00000004
.word 0x04000000
.word 0x04040404
.word 0x00000004
.word 0x00000000
.word 0x04000400
.word 0x00000000
.word 0x04922d91
.word 0x04002900
.word 0x0404042d
.word 0x00000000
.word 0x04040004
.word 0x04040004
.word 0xbf96912c
.word 0x040404bf
.word 0x25bfbfbf
.word 0x002d0404
.word 0x29290000
.word 0x2d290008
.word 0x0028292d
.word 0x2d292929
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x00000491
.word 0x96969192
.word 0x96969696
.word 0x96969696
.word 0xb6049691
.word 0xb6b6b6b6
.word 0xbab6b6b6
.word 0xbfbfbfbf
.word 0x282c0408
.word 0x8d92ad28
.word 0xadadadad
.word 0x0028b1ad
.word 0x04040400
.word 0x00040404
.word 0x0004ad00
.word 0x04000000
.word 0x00000000
.word 0x2d2d0428
.word 0x00000029
.word 0x00000000
.word 0x00000000
.word 0x00040000
.word 0x00000000
.word 0x08280800
.word 0x2d290400
.word 0x97042c04
.word 0x00080000
.word 0x00000404
.word 0x042c0000
.word 0xbf282d30
.word 0x042904bf
.word 0x04bfbfbf
.word 0x042d0424
.word 0x29290000
.word 0x2d2d0008
.word 0x2d2d2929
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x00000491
.word 0x9691912d
.word 0x96969692
.word 0x96289696
.word 0x96049691
.word 0xb6b696b6
.word 0xb6b6b6b6
.word 0xbfbfb729
.word 0x08042d08
.word 0x8d928928
.word 0xadad248d
.word 0x8d20ad8d
.word 0x9a040404
.word 0x8d2c0404
.word 0x000028b1
.word 0x00000000
.word 0x00000000
.word 0x00290400
.word 0x04042804
.word 0x00000000
.word 0x00000000
.word 0x00040000
.word 0x00080000
.word 0x042d042d
.word 0x04000029
.word 0x2c002c28
.word 0x0000002d
.word 0x04290400
.word 0x00080404
.word 0xbfbf0828
.word 0x919191bf
.word 0x29bfbfbf
.word 0x282d0424
.word 0x29290000
.word 0x29080404
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x00002891
.word 0x92929191
.word 0x96969696
.word 0x9691b696
.word 0x968d9196
.word 0xb6b6b691
.word 0xbab6b6b6
.word 0x8e2996bb
.word 0x08080428
.word 0x888dad28
.word 0x88888888
.word 0x91892088
.word 0x04040404
.word 0x282c3004
.word 0x0000008d
.word 0x00000000
.word 0x2c040000
.word 0x00042928
.word 0xb1009104
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00080400
.word 0x00910400
.word 0x04080000
.word 0x28092c04
.word 0x04049f91
.word 0x04082831
.word 0x00002d00
.word 0xbfbf9a04
.word 0x929692bf
.word 0x96bfbfbf
.word 0x29290424
.word 0x04290000
.word 0x2d292d29
.word 0x2d2d292d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x00002d91
.word 0x92969191
.word 0x96969696
.word 0x2d290896
.word 0x96040424
.word 0xb6b6b692
.word 0xbab6bab6
.word 0x96bbbb2d
.word 0x28040404
.word 0x8d8dad28
.word 0x89898989
.word 0x8d898989
.word 0x00000404
.word 0x082c2804
.word 0x00000000
.word 0x00000000
.word 0x04280000
.word 0x00040404
.word 0x04008d04
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00290404
.word 0x00002c04
.word 0x00040409
.word 0x04040400
.word 0x28059b04
.word 0x9628042c
.word 0x00040404
.word 0xbfbfbf31
.word 0x2d96babf
.word 0xbfbfbfbf
.word 0x29292400
.word 0x2d2d0400
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d282d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x00002d91
.word 0x96919191
.word 0x96969696
.word 0x96b60496
.word 0xba929604
.word 0xb696242d
.word 0xb6b6b6ba
.word 0x8d96bbbb
.word 0x04040404
.word 0x24910424
.word 0x28242424
.word 0x048d2828
.word 0x04000404
.word 0x04950400
.word 0x00000000
.word 0x00040000
.word 0x04000404
.word 0x00008d91
.word 0x04040404
.word 0x00040000
.word 0x009b0000
.word 0x00310000
.word 0x04042800
.word 0x04049504
.word 0x08043195
.word 0x28080400
.word 0x2d252997
.word 0x9100042c
.word 0x282d92bf
.word 0xbfbfbf31
.word 0xbfbfbfbf
.word 0x00bbbfbf
.word 0x04290404
.word 0x2d2d2929
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d292d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x00002d91
.word 0x91929191
.word 0x96969696
.word 0x96962996
.word 0x0491b696
.word 0x96b6b691
.word 0x29b68db6
.word 0x95bbbbbb
.word 0x04000404
.word 0xb696b604
.word 0xb6b6b6b6
.word 0x00b6b6b6
.word 0x2cb68d00
.word 0x91282c04
.word 0x002d0000
.word 0x00080000
.word 0xb6000000
.word 0x00000400
.word 0x28040004
.word 0x00000000
.word 0x00000000
.word 0x04042c00
.word 0x04080404
.word 0x2d049131
.word 0x04040491
.word 0x09040428
.word 0x00049709
.word 0x242c0400
.word 0x04040092
.word 0x96969691
.word 0x96969696
.word 0x00929696
.word 0x292d2824
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d28292d
.word 0x2d2d2d2d
.word 0x9191912d
.word 0x00002991
.word 0x9628002d
.word 0x91969696
.word 0x96960491
.word 0x04b69696
.word 0x00000404
.word 0x00000004
.word 0x2cbbbb97
.word 0x04280400
.word 0x00b6b6b5
.word 0xb6000020
.word 0x8891b6b6
.word 0x04b68d29
.word 0x2d31042c
.word 0x00000000
.word 0x00000000
.word 0x8d049100
.word 0x00040000
.word 0x00000000
.word 0x00040004
.word 0x00000000
.word 0x08000004
.word 0x28042800
.word 0x9528042c
.word 0x282d002d
.word 0x00bb2d04
.word 0x00049b00
.word 0x2d082c2d
.word 0x042dbbbb
.word 0xbabbba04
.word 0xbbbbbbbb
.word 0x91bbbbbb
.word 0x2d2d2904
.word 0x292d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x29280404
.word 0x2d2d2d2d
.word 0x28912d2d
.word 0x00000004
.word 0x96040429
.word 0x96969696
.word 0x00000404
.word 0x29950404
.word 0x0000962d
.word 0x00000004
.word 0x08bbbb96
.word 0x04000404
.word 0x28b6b6b6
.word 0xb629298d
.word 0x89b6b6b6
.word 0xb6b6b68d
.word 0x042c28b6
.word 0x000000b2
.word 0x00000000
.word 0x8d91b600
.word 0x00b60000
.word 0x04080000
.word 0x00000028
.word 0x00000000
.word 0x00040428
.word 0x282c0000
.word 0x9b910804
.word 0x91bf0496
.word 0x9bbb2804
.word 0x0400009b
.word 0x24240004
.word 0x04040404
.word 0x24240400
.word 0x04040404
.word 0x04040404
.word 0x2d2d2904
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x04040429
.word 0x2d2d2d2d
.word 0x04282d2d
.word 0x00000004
.word 0x04280404
.word 0x00000004
.word 0x04040404
.word 0x91040829
.word 0x0096968d
.word 0x00000404
.word 0x00bbbbbb
.word 0x04280004
.word 0x89b6b6b6
.word 0xb6202084
.word 0x89b6b6b6
.word 0x91b69188
.word 0x002c04b6
.word 0x95b628b6
.word 0x04960404
.word 0x91b69100
.word 0x04000000
.word 0x00000000
.word 0x04000428
.word 0x00000000
.word 0x04080800
.word 0x04000800
.word 0x9b040400
.word 0x04962c04
.word 0x9b2d0404
.word 0x04000529
.word 0x28040800
.word 0x04042929
.word 0x2d2d2400
.word 0x0000002d
.word 0x2d2d2d00
.word 0x2d2d2904
.word 0x2d2d2d2d
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x2d04002d
.word 0x8d2d0004
.word 0x00912d2d
.word 0x00000004
.word 0x292d0404
.word 0x00292829
.word 0x04040404
.word 0x002d0429
.word 0x002896b6
.word 0x00000000
.word 0x04bbbb25
.word 0x2d042c04
.word 0x28b6b6b6
.word 0xb628b68d
.word 0x04b6b6b6
.word 0x91b6b62d
.word 0x2d2d8cb6
.word 0xb5b6b6b6
.word 0x00040404
.word 0xbab6b600
.word 0x00240024
.word 0x00910000
.word 0x00000000
.word 0x28000000
.word 0x2c040408
.word 0x00000904
.word 0x322d3200
.word 0x00000431
.word 0x00280008
.word 0x04240000
.word 0x28280804
.word 0x2904bbbf
.word 0xbfbf2989
.word 0x8d2824bb
.word 0xbfbfbbb2
.word 0x2d2d2924
.word 0x2d2d2d29
.word 0x2d2d2d29
.word 0x2d2d2d2d
.word 0x2d2d2d2d
.word 0x04040000
.word 0x00000404
.word 0x00040000
.word 0x00000404
.word 0x04040000
.word 0x04042904
.word 0x04040404
.word 0x2d000029
.word 0x04ba2829
.word 0x00040000
.word 0x0892bfbf
.word 0x04080428
.word 0x2db6b6b6
.word 0xb6298d24
.word 0x04b6b6b6
.word 0xb6b69132
.word 0x2d08b6b5
.word 0x28b6b6b6
.word 0x082c3104
.word 0x0024b624
.word 0x2d000000
.word 0x00000000
.word 0x00000000
.word 0x00890000
.word 0x00000004
.word 0x00000000
.word 0x9f08972d
.word 0x00000000
.word 0x00002e08
.word 0x002d9b00
.word 0x29290800
.word 0x0029bfbb
.word 0xbfbf0091
.word 0x8dad24bf
.word 0xbbbfbf8d
.word 0x2d2d2904
.word 0x29292d29
.word 0x2d2d2d2d
.word 0x2d2d2d29
.word 0x2904002d
.word 0x00000429
.word 0x04040404
.word 0x00000004
.word 0x00000000
.word 0x04040000
.word 0x04042d2d
.word 0x04040400
.word 0x29000404
.word 0x29960429
.word 0x04000000
.word 0xbfbfbfbf
.word 0x08083100
.word 0x8db6b6b6
.word 0xb6248904
.word 0x04b6b6b6
.word 0xb6b68c31
.word 0x2d8d302c
.word 0x04b6b6b6
.word 0x28080400
.word 0xb58db6ba
.word 0x008900b6
.word 0x04000000
.word 0x00000000
.word 0x00890000
.word 0x00000000
.word 0x002d0400
.word 0x9bbf9204
.word 0x04090004
.word 0x00009504
.word 0x00040004
.word 0x2d2d2d00
.word 0x9192bfbf
.word 0xbfbf2491
.word 0x8dad91bf
.word 0xbfbfbf89
.word 0x2d2d2d24
.word 0x2d2d2d2d
.word 0x292d292d
.word 0x29292d29
.word 0x0400042d
.word 0x00000400
.word 0x00040004
.word 0x00000000
.word 0x00000804
.word 0x00000008
.word 0x00040004
.word 0x04040429
.word 0x04000000
.word 0x002d9604
.word 0x04040000
.word 0xbfbfbfbf
.word 0x2d000404
.word 0xadb6b691
.word 0xb68488ad
.word 0x8db691b6
.word 0x2cb6b68d
.word 0x91b6b6b1
.word 0xb6b6b6b1
.word 0x282c0000
.word 0x95b6b6b6
.word 0x00002d28
.word 0x00000000
.word 0x00000000
.word 0x00200000
.word 0x00000000
.word 0x00040400
.word 0xbb972dbb
.word 0x00280000
.word 0x962d3000
.word 0x04000096
.word 0x2d2d2900
.word 0x2c92bfbf
.word 0xbfbf898d
.word 0xadad92bf
.word 0xbfbfbf89
.word 0x2d292904
.word 0x2d29292d
.word 0x2929292d
.word 0x04292829
.word 0x08000404
.word 0x00000004
.word 0x00040004
.word 0x00000004
.word 0x00000408
.word 0x00040004
.word 0x00000000
.word 0x00000000
.word 0x28000029
.word 0x00002d29
.word 0x04040000
.word 0xbfbfbfbf
.word 0x08042c00
.word 0xae96b691
.word 0xb68d20ad
.word 0xb6b6b691
.word 0xb6b6b6b6
.word 0xb1b7b2b6
.word 0x28b68d91
.word 0x04000404
.word 0xb6b6b68d
.word 0x280000b6
.word 0x00002400
.word 0x00000000
.word 0x00000000
.word 0x2d000000
.word 0x08090500
.word 0x2d9f9b9f
.word 0x04042808
.word 0x002d0091
.word 0x0004322e
.word 0xbb9a082d
.word 0x96b6bfbf
.word 0xbfbf9600
.word 0x929296bf
.word 0xbfbfbf91
.word 0x2d290404
.word 0x29292929
.word 0x00000429
.word 0x28292908
.word 0x28002d00
.word 0x00000429
.word 0x04040400
.word 0x04000004
.word 0x00000004
.word 0x00000004
.word 0x00000000
.word 0x00000000
.word 0x00000029
.word 0x04002904
.word 0x00000404
.word 0xbfbfbfbf
.word 0x00000404
.word 0xae8db628
.word 0xb6b629ae
.word 0xb6b6b6b6
.word 0xb6b6b6b6
.word 0xb6bbb2b6
.word 0x2891b6b6
.word 0x28002804
.word 0xb6b6b6b6
.word 0x00000024
.word 0x0000008d
.word 0x00000000
.word 0x04000000
.word 0x00040408
.word 0x04003700
.word 0x092d329b
.word 0x00040431
.word 0x2d920428
.word 0x0400002d
.word 0xbbbb312c
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0x29290004
.word 0x29042929
.word 0x922d0000
.word 0x28292991
.word 0x04002d00
.word 0x00040400
.word 0x04000000
.word 0x04000000
.word 0x00000000
.word 0x00000000
.word 0x00000004
.word 0x00000000
.word 0x04000004
.word 0x002d0400
.word 0x00000000
.word 0xbfbfbfbf
.word 0x2c282c28
.word 0xb291b624
.word 0xb69124b2
.word 0xb6b6b6b6
.word 0xb2b6b6b6
.word 0xb6bbb2b6
.word 0x8d9124b6
.word 0x00000000
.word 0x04b6b6b6
.word 0x00000028
.word 0x00040000
.word 0x00000004
.word 0x04000020
.word 0x00003100
.word 0x04bf3200
.word 0x0904bf08
.word 0x96080000
.word 0x9b003032
.word 0x04000000
.word 0xbbbb9600
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0x29290029
.word 0x29290000
.word 0x912d2d00
.word 0x2829292d
.word 0x00002d00
.word 0x00000000
.word 0x00000028
.word 0x00000028
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x29002900
.word 0x00000000
.word 0xbfbfbfbf
.word 0x04042808
.word 0xb2b52924
.word 0xb6b6b6b6
.word 0xb6b6b6b6
.word 0x28b6b6b6
.word 0xb6bfb2b2
.word 0x288db6b6
.word 0x29000000
.word 0x00b6b6b6
.word 0x89000004
.word 0x00000000
.word 0x00000000
.word 0x28000000
.word 0x00000428
.word 0x31310004
.word 0x002c0904
.word 0x00009f00
.word 0x002d28bb
.word 0x00000400
.word 0xbfbb0404
.word 0xbfbfbf92
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0x04290029
.word 0x29298d00
.word 0x00040400
.word 0x29292900
.word 0x00000804
.word 0x00000000
.word 0x00000004
.word 0x00000404
.word 0x00000004
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x29000400
.word 0x04000004
.word 0xbfbfbfbf
.word 0x04042d04
.word 0xb2282824
.word 0xb62404bb
.word 0xb6b6b6b6
.word 0xb6b6b6b6
.word 0xb6bfb2b2
.word 0x2891b6b6
.word 0x00000404
.word 0x04b6b6b6
.word 0x00009100
.word 0x04000000
.word 0x00000000
.word 0x24000000
.word 0x0000042c
.word 0x2d089b00
.word 0x2d000400
.word 0x29040400
.word 0x04009b09
.word 0x00000004
.word 0x2d040800
.word 0xbfbfbf04
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0x04000000
.word 0x29298d04
.word 0x00040400
.word 0x29292900
.word 0x00000800
.word 0x00000000
.word 0x00000000
.word 0x00000004
.word 0x00000000
.word 0x04000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x04000000
.word 0x28040400
.word 0xbfbf2904
.word 0x00040408
.word 0xbb288d24
.word 0xb60000bb
.word 0x24b6b6b6
.word 0xb6b6b629
.word 0x31bfb2b2
.word 0x288db6b6
.word 0x00000000
.word 0x91b6b6b6
.word 0x0000008d
.word 0x00000000
.word 0x00000000
.word 0x04000000
.word 0x04040404
.word 0x09042900
.word 0x29000008
.word 0x96950896
.word 0x04040004
.word 0x00080000
.word 0x082d2808
.word 0xbbbbbbbf
.word 0xbfbfbfbb
.word 0xb6bbbbbb
.word 0xbbbb968d
.word 0x04040000
.word 0x29292d00
.word 0x00000400
.word 0x292d2900
.word 0x04000900
.word 0x00040000
.word 0x00000000
.word 0x04000000
.word 0x00040000
.word 0x00000000
.word 0x00000400
.word 0x00000000
.word 0x00000000
.word 0x04000000
.word 0x2d040400
.word 0x04040404
.word 0x3228bb28
.word 0xb6242824
.word 0xb60000bb
.word 0x24b6b6b6
.word 0xb6b6b68d
.word 0x2ebfb6b2
.word 0x2928b6b6
.word 0x04000004
.word 0xbab6b6b6
.word 0x002824ba
.word 0x00000000
.word 0x00080000
.word 0x89000000
.word 0x952c0000
.word 0x00050804
.word 0x00000404
.word 0x2d000400
.word 0x00000000
.word 0x00040000
.word 0x28040404
.word 0xb689bfbf
.word 0xbfbf248d
.word 0x8d89b6bf
.word 0xbfbfbf28
.word 0x24040004
.word 0x29292904
.word 0x00000400
.word 0x29292900
.word 0x00040400
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x04000000
.word 0x00040400
.word 0x04040400
.word 0xbf2c0404
.word 0x00280000
.word 0xad282884
.word 0xb6202492
.word 0x89b6b6b6
.word 0xb6b6b689
.word 0x00bfb2b6
.word 0xb6b6b6b6
.word 0x04000024
.word 0xb6b6b68d
.word 0x04b6babf
.word 0x00000400
.word 0x00040000
.word 0x31040000
.word 0x0400042c
.word 0x002d9604
.word 0xbf2c0404
.word 0x28090009
.word 0x09000400
.word 0x00040004
.word 0x2d002d04
.word 0xb724bfbf
.word 0xbfbf2929
.word 0x8989bbbf
.word 0xbfbfbf28
.word 0x04000024
.word 0x29292904
.word 0x00040404
.word 0x29292904
.word 0x00000404
.word 0x00000400
.word 0x00040400
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00040000
.word 0x00000400
.word 0x00290004
.word 0x28040092
.word 0x0404b684
.word 0xb620842d
.word 0x04b6b6b6
.word 0xb6b6b62d
.word 0x00bfb7b6
.word 0xb6b692b6
.word 0x24290089
.word 0xb6b6b62d
.word 0x040008ba
.word 0x04000000
.word 0x00008d00
.word 0x04000000
.word 0x2c00042d
.word 0x04912900
.word 0x04310400
.word 0x080004bf
.word 0xbb000400
.word 0x04000400
.word 0x0800042d
.word 0x8485bfbb
.word 0xbfbf2889
.word 0x2989bfbf
.word 0xbfbfbf2d
.word 0x24000004
.word 0x29292904
.word 0x04290428
.word 0x29292904
.word 0x00000404
.word 0x00000000
.word 0x00000400
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000400
.word 0x04000400
.word 0x08042d04
.word 0x0404b588
.word 0xb6208429
.word 0x04b6b6b6
.word 0xb6b6b62d
.word 0x00bfbbb6
.word 0xb6b604b6
.word 0x2404048d
.word 0x2c04b604
.word 0x000004ba
.word 0x00000000
.word 0x00282800
.word 0xb6040000
.word 0x04000024
.word 0x008d0000
.word 0x040404bf
.word 0x04002d9b
.word 0x9b9bbb00
.word 0x28000497
.word 0x2c2c0491
.word 0x8424bfbb
.word 0xbbbf2484
.word 0x298dbfbf
.word 0xbfbbbb91
.word 0x28000424
.word 0x29292904
.word 0x2d092929
.word 0x29292929
.word 0x00000404
.word 0x04000000
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x00002d00
.word 0x00000000
.word 0x00000000
.word 0x04000000
.word 0x04000000
.word 0x04000000
.word 0x00002800
.word 0x96040000
.word 0x048d9189
.word 0xb6248492
.word 0x04b6b6b6
.word 0xb6b6b62d
.word 0x00bfbfb6
.word 0xb6b604b6
.word 0x0004008e
.word 0xb6b6b624
.word 0x00290404
.word 0x24ba0091
.word 0x00000000
.word 0x8dba0400
.word 0x00000024
.word 0x91043000
.word 0x00322d96
.word 0x0000009b
.word 0xbb000900
.word 0x00040000
.word 0x2d2d0404
.word 0x898dbfbf
.word 0xbfbb928d
.word 0x918dbfbf
.word 0xbfbbbf92
.word 0x29000424
.word 0x29292904
.word 0x04042928
.word 0x04042904
.word 0x00040404
.word 0x04000000
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00280000
.word 0x00000000
.word 0x00000000
.word 0x04000000
.word 0x04040028
.word 0x29040405
.word 0x29b62889
.word 0xb6918d8e
.word 0x89b6b6b6
.word 0xb6b6b68d
.word 0x8dbfbfb6
.word 0xb6b604b6
.word 0x000400b6
.word 0xb6b6b604
.word 0xb6b69196
.word 0x00000000
.word 0x002d2c00
.word 0x04ba0404
.word 0x0430318d
.word 0x2c280804
.word 0x299b042e
.word 0x00bb9b96
.word 0x32000900
.word 0x04000409
.word 0x04310404
.word 0xbfbf24bf
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbbbfbfbf
.word 0x29042904
.word 0x29290404
.word 0x04000004
.word 0x29292929
.word 0x00000429
.word 0x00000000
.word 0x04040004
.word 0x00000804
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x28040000
.word 0x04040000
.word 0x00000000
.word 0x04bf0024
.word 0x04000404
.word 0x288d2889
.word 0xb604b68e
.word 0xb6b6b6b6
.word 0xb6b6b6b6
.word 0xb6bfbfb6
.word 0x8db628b6
.word 0x29290091
.word 0xb6b6b629
.word 0xb6b6bab6
.word 0x00240095
.word 0x04000000
.word 0x2cba8404
.word 0x040408b2
.word 0x082c2804
.word 0x3200002d
.word 0x00bb0000
.word 0x09040000
.word 0x04000004
.word 0xbf919608
.word 0xbfbf08bf
.word 0xbbbfbfbf
.word 0xbfbfbfbb
.word 0xbfbfbfbf
.word 0x290429b6
.word 0x29290004
.word 0x29282828
.word 0x04292929
.word 0x00040000
.word 0x00000000
.word 0x04000000
.word 0x04000408
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x968d0000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x04bf2504
.word 0x29000000
.word 0x91b62889
.word 0xb604b6b2
.word 0xb6b6b6b6
.word 0xb6b6b6b6
.word 0xb6bfbab6
.word 0x8db600b6
.word 0x292d0091
.word 0xb6b62429
.word 0xb6bababa
.word 0x00b6baba
.word 0x00000404
.word 0xb1ba0004
.word 0x2900008d
.word 0x2d289a31
.word 0x9b049604
.word 0x9b9bbf05
.word 0x00000429
.word 0x00000404
.word 0x08bb9604
.word 0xbfbfbfbf
.word 0xbfbfbfbf
.word 0xbfbfbfbb
.word 0xbbbbbbbf
.word 0x04042996
.word 0x29292804
.word 0x29292929
.word 0x042d2929
.word 0x00280404
.word 0x00000000
.word 0x00000000
.word 0x00000408
.word 0x00000000
.word 0x00000000
.word 0x002d0000
.word 0x00000800
.word 0x00000000
.word 0x00000000
.word 0x04000000
.word 0x04bf0000
.word 0x00000000
.word 0x8d8d28ad
.word 0xb68db6bb
.word 0xb6b6b6b6
.word 0xb6b6b6b6
.word 0xb6bfb6b6
.word 0x8d2d04b6
.word 0x2428008d
.word 0xb6b60029
.word 0xb6bababa
.word 0x24b6bab6
.word 0x91b60400
.word 0x24ba2491
.word 0x00000004
.word 0x28282d00
.word 0x9b2d2c04
.word 0xbbbbbbbb
.word 0x00040400
.word 0x0000bb04
.word 0x08009204
.word 0xbfbfbfbb
.word 0xbfbfbfbf
.word 0xbfbfbbbf
.word 0xbbbfbfbf
.word 0x292804b6
.word 0x29292929
.word 0x2929292d
.word 0x29292d29
.word 0x00000000
.word 0x00002804
.word 0x00000000
.word 0x00000400
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x0091048d
.word 0x00002d00
.word 0x00000000
.word 0x04000000
.word 0x00000400
.word 0x04000000
.word 0x28288db1
.word 0xb68d8dbf
.word 0xb6b6b6b6
.word 0xb6b6b6b6
.word 0xb6bfb6b6
.word 0x240424b6
.word 0x29290024
.word 0xb6b6002d
.word 0xb6babab6
.word 0x8dbabab6
.word 0x91bab604
.word 0x2d2cb691
.word 0x00000000
.word 0x2c2c0429
.word 0x96312c30
.word 0x04bbbbbb
.word 0x00000800
.word 0x00000000
.word 0x2d000400
.word 0xbbbfbb96
.word 0xbfbbbbbb
.word 0xbbbbbfbf
.word 0xbbbfbfbf
.word 0x29292904
.word 0x29292929
.word 0x2929292d
.word 0x2d2d2d29
.word 0x00000000
.word 0x00002800
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00048d00
.word 0x00009100
.word 0x00000000
.word 0x00040000
.word 0x00bfbf00
.word 0x00000000
.word 0x242489b2
.word 0xb62824bf
.word 0xb6b6b68d
.word 0xb6b6b6b6
.word 0xb6bbb6b6
.word 0x242d04b6
.word 0x04042424
.word 0x96b6042d
.word 0xb6bababa
.word 0xb6babab6
.word 0x91ba00b6
.word 0x2c04b691
.word 0x2400002c
.word 0x04040028
.word 0xbf9b0804
.word 0x28bb96bb
.word 0x04000408
.word 0x00040004
.word 0x00002831
.word 0x28bfbb04
.word 0xbbbf2d2d
.word 0x2929bbbf
.word 0xbbbbbb29
.word 0x29292d2d
.word 0x292d2929
.word 0x2929292d
.word 0x292d2d29
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000400
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00280000
.word 0x00bfbf04
.word 0x00000000
.word 0x242428b6
.word 0xb6b624bf
.word 0x89b6b6b6
.word 0xb6b6b600
.word 0xb2ba91b6
.word 0x288d00b6
.word 0x04290024
.word 0x92b6092d
.word 0xb6ba9696
.word 0xbababab6
.word 0x91ba00b6
.word 0x2c042891
.word 0x0400002c
.word 0x2d280429
.word 0x96282c2c
.word 0x049b2929
.word 0x002c0028
.word 0x00280404
.word 0x00002928
.word 0x24bf2900
.word 0xbfbfb692
.word 0x2904bfbf
.word 0xbbbbbb29
.word 0x29298d29
.word 0x29292929
.word 0x292d2929
.word 0x2d292929
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00003196
.word 0x00000000
.word 0x08000000
.word 0x00bfbf24
.word 0x00000000
.word 0x002889b6
.word 0xb6b600bf
.word 0xb28db6b6
.word 0xb6b628b2
.word 0xb1968db6
.word 0x282800b6
.word 0x282d0000
.word 0x9291912d
.word 0xb6ba9696
.word 0xbab6bab6
.word 0x91000000
.word 0x042828b1
.word 0x00280000
.word 0x08040028
.word 0x312c042c
.word 0x00960905
.word 0x002d0804
.word 0x00040028
.word 0x00002d04
.word 0x28bb0400
.word 0xbb922d92
.word 0x2529bfbf
.word 0xbbbbbb29
.word 0x29298d2d
.word 0x29292929
.word 0x29292929
.word 0x04292d2d
.word 0x00000004
.word 0x04000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000029
.word 0x00969504
.word 0x00000000
.word 0x04000000
.word 0x08bfbf28
.word 0x3136322d
.word 0x00002db6
.word 0xb60484bf
.word 0xb18d918d
.word 0xba96bbba
.word 0xa98dbfbf
.word 0xb62829ad
.word 0x04290400
.word 0x00b6ba29
.word 0xb6baba04
.word 0xba24b6b6
.word 0x91000000
.word 0x28049191
.word 0x00000030
.word 0x002c0004
.word 0x282d2c28
.word 0x00090420
.word 0x04282c04
.word 0x00282900
.word 0x00002800
.word 0x28bb0004
.word 0x24290004
.word 0x0425bbbb
.word 0xbbbbbb25
.word 0x29292d29
.word 0x29292929
.word 0x29292d29
.word 0x04292d29
.word 0x00000400
.word 0x04000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0xbb929224
.word 0xbfbfbfbf
.word 0x24048db6
.word 0x8e8e89bf
.word 0xbfbfbfb7
.word 0xbf050505
.word 0xb18db6ae
.word 0xb6b6b6b2
.word 0x29299696
.word 0x00b6bb24
.word 0xb6b6ba00
.word 0xb691b6b6
.word 0x91ba0000
.word 0x2d00b691
.word 0x00000031
.word 0x04040429
.word 0x28312c04
.word 0x00000500
.word 0x04042828
.word 0x00000004
.word 0x00000400
.word 0x29bb0004
.word 0x00960404
.word 0x8d8dbbbb
.word 0x9692b68d
.word 0x29299629
.word 0x29292929
.word 0x29292929
.word 0x2929292d
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0xbf929228
.word 0xbfbbbbbf
.word 0x2d2d8d91
.word 0x040496bf
.word 0xbbbfbf04
.word 0x04040405
.word 0x0404bba9
.word 0x04b6b604
.word 0x29289629
.word 0x24b62904
.word 0xb624ba24
.word 0x8db5b6b6
.word 0x91ba0000
.word 0x2c00b691
.word 0x00000000
.word 0x08002d24
.word 0x28282824
.word 0x000400b6
.word 0x04000804
.word 0x28000400
.word 0x0004292d
.word 0x92960004
.word 0x00040404
.word 0x92969600
.word 0x92040092
.word 0x28292d2e
.word 0x29292929
.word 0x29292929
.word 0x29292929
.word 0x00000000
.word 0x00000004
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00002d00
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0xbf929224
.word 0x2d0428bf
.word 0x082c8d28
.word 0x04049abf
.word 0x92bfbf04
.word 0x04050904
.word 0x0428bba9
.word 0x04ba9528
.word 0x04049609
.word 0x89240029
.word 0xb68dba89
.word 0x89b6bab6
.word 0x91b60000
.word 0x28bab691
.word 0x00000004
.word 0x2c2c0400
.word 0x04042c04
.word 0x09290028
.word 0x04002c2c
.word 0x2c000800
.word 0x04040404
.word 0x32322e04
.word 0x002d2e2e
.word 0x96969696
.word 0x92000096
.word 0x04292d2e
.word 0x29292929
.word 0x29292929
.word 0x29292929
.word 0x00000400
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000004
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x04bfbf28
.word 0x310028bf
.word 0x28288d04
.word 0x000409bf
.word 0xbf962904
.word 0x2dbfbfbf
.word 0x90282892
.word 0x09b62c91
.word 0x29049605
.word 0xb2b62904
.word 0xb6b6ba89
.word 0x8db6b6ba
.word 0x8db60000
.word 0x0828b6b6
.word 0x00000004
.word 0x082c2c00
.word 0x00302804
.word 0x25040404
.word 0x29042c28
.word 0x30040429
.word 0x00000429
.word 0x2d2e2d00
.word 0x002d2d2e
.word 0x92929696
.word 0x92000596
.word 0x29049204
.word 0x29290000
.word 0x29292929
.word 0x29292929
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x04000000
.word 0x00000029
.word 0x00000000
.word 0x00000000
.word 0x00959600
.word 0x95280000
.word 0x00000000
.word 0x00000000
.word 0x04bfbf28
.word 0x080404bf
.word 0x00048d04
.word 0xbb96bf96
.word 0x082d2c29
.word 0x2c2c28bb
.word 0x2c2c2896
.word 0x2d2c282c
.word 0x29009604
.word 0xbbb6042d
.word 0xb6b6ba84
.word 0x24b6b6b6
.word 0x8db600b2
.word 0x9028b6b2
.word 0x00000004
.word 0x04042800
.word 0x24040400
.word 0x04042928
.word 0x2d082900
.word 0x282d2929
.word 0x00290504
.word 0x2d922d04
.word 0x00042d2d
.word 0x96969604
.word 0x29000092
.word 0x0404922e
.word 0x29290404
.word 0x29000429
.word 0x29292929
.word 0x00040429
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000004
.word 0x00000000
.word 0x00000000
.word 0x00969600
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x2cbfbb24
.word 0x2c2c2cbb
.word 0x04048d28
.word 0x0429082d
.word 0x2c082c28
.word 0x2c28282c
.word 0x282c282c
.word 0x2d282c2c
.word 0x00003105
.word 0xbfb60429
.word 0x96b6ba88
.word 0x04b6b6b6
.word 0x91b600b2
.word 0x082d8d91
.word 0x00000400
.word 0x00000400
.word 0x04000000
.word 0x2d05922c
.word 0x2d040000
.word 0x91bf96bf
.word 0x28289100
.word 0x24962904
.word 0x00292d2d
.word 0x92962400
.word 0x04040492
.word 0x042d2d2e
.word 0x04000404
.word 0x29040404
.word 0x00042929
.word 0x00000000
.word 0x00080400
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x2d918d00
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x2c282905
.word 0x2c2c2c2c
.word 0x2c2c8d28
.word 0x04000492
.word 0x282d0828
.word 0x042c082c
.word 0x00082828
.word 0x2d282828
.word 0x29009129
.word 0x9200282d
.word 0xb6b6b6a9
.word 0x00b6bab6
.word 0x8db60024
.word 0x00292932
.word 0x00002800
.word 0x04002800
.word 0x00000400
.word 0x96080404
.word 0x2d04ba29
.word 0x00bfbfbf
.word 0x96ba0824
.word 0x9abb2dba
.word 0x04042831
.word 0x04040404
.word 0x04040404
.word 0x04040429
.word 0x04040404
.word 0x04040404
.word 0x04040404
.word 0x00000400
.word 0x00002900
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x962d9100
.word 0x00000004
.word 0x00000000
.word 0x00000000
.word 0x08082d00
.word 0x2c083008
.word 0x92928d08
.word 0x00040504
.word 0x0804002d
.word 0x08082c08
.word 0x0028282c
.word 0x2d082c30
.word 0x0404b696
.word 0x89962828
.word 0xb6b6b6ad
.word 0x04b6bab6
.word 0x8db628b6
.word 0x00bf2d92
.word 0x00002804
.word 0x04002400
.word 0x29040004
.word 0x2c08b504
.word 0x2d2c912c
.word 0x92bfba2d
.word 0x8d8dba04
.word 0x0424298d
.word 0x00900404
.word 0x04040404
.word 0x04040404
.word 0x00000404
.word 0x04040404
.word 0x04040000
.word 0x04040404
.word 0x00000004
.word 0x00000400
.word 0x00000000
.word 0x00000000
.word 0x04002900
.word 0x00000000
.word 0x00000000
.word 0x91042900
.word 0x00000400
.word 0x00000000
.word 0x00000000
.word 0x2c042904
.word 0x08042c08
.word 0x9292912d
.word 0x00040496
.word 0x08280428
.word 0x28082808
.word 0x2c08282c
.word 0x0428282c
.word 0x2800b62d
.word 0xba29048d
.word 0xb6b6b6ba
.word 0xbfb6bab6
.word 0x8db6b6ba
.word 0x0000008e
.word 0x00040000
.word 0x00000000
.word 0x2d2d2804
.word 0x2c313028
.word 0x2c2c2c2c
.word 0x922d2d31
.word 0x2d918d95
.word 0x04042808
.word 0x08080404
.word 0x2d2c2c2c
.word 0x0428282c
.word 0x04040404
.word 0x00000004
.word 0x00000404
.word 0x00000004
.word 0x00000000
.word 0x00040404
.word 0x00000004
.word 0x00000000
.word 0x04000000
.word 0x00000000
.word 0x00000400
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x08280800
.word 0x2c2c2c2c
.word 0x9292282c
.word 0x282d0404
.word 0x28282808
.word 0x2c282c08
.word 0x91282c28
.word 0x92912d08
.word 0x042d9296
.word 0x8d282929
.word 0x2d2d8d2d
.word 0x92928d2d
.word 0x91920092
.word 0x042c0400
.word 0x08042c28
.word 0x08282804
.word 0x2c282808
.word 0x302c2c28
.word 0x312c2c91
.word 0x2d08082c
.word 0x082c9128
.word 0x04040404
.word 0x04040404
.word 0x2c2c2c2c
.word 0x2c2c2d2c
.word 0x282d282c
.word 0x2c2c2c28
.word 0x2c2c2c28
.word 0x04040828
.word 0x04000400
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00040000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x2c080408
.word 0x282c282d
.word 0x922d2c2c
.word 0x28282c28
.word 0x04280408
.word 0x2891ba08
.word 0x91929292
.word 0x05052424
.word 0x29040505
.word 0x052d2828
.word 0x25250505
.word 0x29050405
.word 0x00000004
.word 0x04002800
.word 0x04040000
.word 0x31282804
.word 0x282c3008
.word 0x2c283031
.word 0x2c2c2c2c
.word 0x0808282c
.word 0x04040408
.word 0x04040404
.word 0x04040404
.word 0x2c282804
.word 0x2c2d282c
.word 0x0429042c
.word 0x2c2c2c04
.word 0x2c2c2c2c
.word 0x04002d2d
.word 0x2c08042c
.word 0x00280808
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000400
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00042c91
.word 0x28282c28
.word 0x9691b631
.word 0x92929296
.word 0x0404248d
.word 0x05050505
.word 0x05050505
.word 0x29040405
.word 0x082c2804
.word 0x2c2d2908
.word 0x00040404
.word 0x04040404
.word 0x00040400
.word 0x04040000
.word 0x2c310404
.word 0x3091302c
.word 0x302c2c2c
.word 0x282c3030
.word 0x28289030
.word 0x0404042c
.word 0x04040404
.word 0x04040404
.word 0x04080404
.word 0x04040404
.word 0x04280804
.word 0x04040408
.word 0x04080808
.word 0x04082804
.word 0x04042c04
.word 0x04000028
.word 0x00000004
.word 0x04040404
.word 0x00040400
.word 0x04040404
.word 0x04000000
.word 0x28080404
.word 0x282c0808
.word 0x04040804
.word 0x00000000
.word 0x00000000
.word 0x912d8d91
.word 0x292d9292
.word 0x04042524
.word 0x092d2929
.word 0x04040404
.word 0x04040404
.word 0x04040404
.word 0x28040404
.word 0x2c2c3031
.word 0x2c309190
.word 0x30303030
.word 0x2c2c2c28
.word 0x282c2c2c
.word 0x00040404
.word 0x2c2c2c28
.word 0x302c2c2c
.word 0x2c2c302c
.word 0x2c2c2c2c
.word 0x082c912c
.word 0x28082c08
.word 0x04280808
.word 0x04040404
.word 0x2c080808
.word 0x08082804
.word 0x04040804
.word 0x08040408
.word 0x082c0804
.word 0x08952804
.word 0x04042808
.word 0x04040404
.word 0x04042404
.word 0x04040404
.word 0x28040404
.word 0x08080404
.word 0x2c000000
.word 0x08080808
.word 0x0828282c
.word 0x08282808
.word 0x04280428
.word 0x00042804
.word 0x04040404
.word 0x29290504
.word 0x29052929
.word 0x29042929
.word 0x292d292d
.word 0x2992922d
.word 0x912d0404
.word 0x2c2c3131
.word 0x2c30302c
.word 0x2c2c3030
.word 0x2c2c2c30
.word 0x2c2c2c2c
.word 0x302c3091
.word 0x2c2c302c
.word 0x91919191
.word 0x2c8d9191
.word 0x2c2c2c28
.word 0x2c28282c
.word 0x31919131
.word 0x3030312c
.word 0x31303030
.word 0x90309530
.word 0x2c2c302c
.word 0x082c0428
.word 0x302c2c2c
.word 0x0804282c
.word 0x08040808
.word 0x04080808
.word 0x04040404
.word 0x04040404
.word 0x2c2c3028
.word 0x2c302c2c
.word 0x2c312c2c
.word 0x282c2c2c
.word 0x28000000
.word 0x2c282c2c
.word 0x2c2c2c2c
.word 0x2c28282c
.word 0x082c2c28
.word 0x04040408
.word 0x04040404
.word 0x04042804
.word 0x25290404
.word 0x24040429
.word 0x31040404
.word 0x282c2828
.word 0x312c2c95
.word 0x2c2c312c
.word 0x2c2c2c2c
.word 0x3030302c
.word 0x2c2c312c
.word 0x2c2c2c30
.word 0x2c2c2c30
.word 0x302c9130
.word 0x91919130
.word 0x90909191
.word 0x30303030
.word 0x2c919495
.word 0x30909030
.word 0x90909530
.word 0x2c303090
.word 0x302c302c
.word 0x2c30912c
.word 0x2c31302c
.word 0x2c2c282c
.word 0x2c042c08
.word 0x08082c2c
.word 0x28280808
.word 0x2c2c2c2c
.word 0x952c312c
.word 0x2c2c3130
.word 0x312c902c
.word 0x2c2c302c
.word 0x302c2c2c
.word 0x2c000000
.word 0x2c2c2c2c
.word 0x2c2c2c2c
.word 0x282c2c2c
.word 0x08288c2c
.word 0x04040408
.word 0x2c2c312c
.word 0x2c2c2c2c
.word 0x2c312c28
.word 0x2c2c2c2d
.word 0x2c91962c
.word 0x2c302c2c
.word 0x2c302c2c
.word 0x2c2c312c
.word 0x2c2c2c30
.word 0x902c3030
.word 0x3090302c
.word 0x30309030
.word 0x90303030
.word 0x30309090
.word 0x95919530
.word 0x30309590
.word 0x90303090
.word 0x30909990
.word 0x3030902c
.word 0x2c303090
.word 0x9030302c
.word 0x30309591
.word 0x2c302c30
.word 0x9530302c
.word 0x9130302c
.word 0x2c303030
.word 0x302c3028
.word 0x31302c2c
.word 0x2c289530
.word 0x30952830
.word 0x2c2c2c30
.word 0x30302c2c
.word 0x2c30912c
.word 0x302c3090
.word 0x2c000000
.word 0x2c2c2c2c
.word 0x082c2c2c
.word 0x0404282c
.word 0x04040404
.word 0x28040428
.word 0x2c2c302c
.word 0x2c2c3030
.word 0x912c912c
.word 0x2c2c3030
.word 0x2c2c9030
.word 0x30903030
.word 0x302c3030
.word 0x2c902c2c
.word 0x91302c2c
.word 0x30302c30
.word 0x2c309090
.word 0x3030302c
.word 0x2c303030
.word 0x30303090
.word 0x95959030
.word 0x2c959590
.word 0x30913091
.word 0x2c2c9030
.word 0x2c302c95
.word 0x30302c2c
.word 0x30912c2c
.word 0x9130952c
.word 0x2c309191
.word 0x3191912c
.word 0x30903095
.word 0x082c2c30
.word 0x2c302c30
.word 0x302c3030
.word 0x30302c90
.word 0x3030302c
.word 0x2c2c2c31
.word 0x2c282c2c
.word 0x2c282c2c
.word 0x30302c30
.word 0x2c000000
.word 0x2c30282c
.word 0x2c2c2c2c
.word 0x28282c2c
.word 0x8c280408
.word 0x00040400
.word 0x312c2c30
.word 0x3030912c
.word 0x3030302c
.word 0x9130302c
.word 0x30303030
.word 0x30302c30
.word 0x2c30952c
.word 0x2c30302c
.word 0x302c9130
.word 0x91303091
.word 0x30953030
.word 0x9191302c
.word 0x3030302c
.word 0x90289130
.word 0x912c2c2c
.word 0x91303030
.word 0x302c952c
.word 0x2c91302c
.word 0x2c2c9130
.word 0x2c903030
.word 0x30302c30
.word 0x30302c2c
.word 0x2c2c3030
.word 0x90302831
.word 0x28303030
.word 0x2c31302c
.word 0x3030912c
.word 0x2c302c30
.word 0x912c2c31
.word 0x302c3095
.word 0x30303030
.word 0x2c953028
.word 0x2c302c2c
.word 0x082c2c31
.word 0x91000000
.word 0x2c2c302c
.word 0x2c2c302c
.word 0x28282c2c
.word 0x04040408
.word 0x04040404
.word 0x91912c30
.word 0x302c2c91
.word 0x2c2c3095
.word 0x3091952c
.word 0x2c2c9591
.word 0x302c2c30
.word 0x2c2c2c2c
.word 0x91302c30
.word 0x3030312c
.word 0x3091302c
.word 0x30953030
.word 0x30303030
.word 0x30303030
.word 0x30902c91
.word 0x2c309030
.word 0x2c283030
.word 0x08912c30
.word 0x2c2c9530
.word 0x30303030
.word 0x2c2c3030
.word 0x30302c95
.word 0x31313030
.word 0x302c2c2c
.word 0x2c2c3095
.word 0x95903131
.word 0x2c2c2c2c
.word 0x2c2c2c30
.word 0x302c3030
.word 0x2c91ba31
.word 0x2c2c2c91
.word 0x2c953031
.word 0x2c2c2c30
.word 0x2c302c2c
.word 0x2c2c282c
.word 0x2c000000
.word 0x2c8c2c2c
.word 0x2c902c2c
.word 0x2828282c
.word 0x2c2c0408
.word 0x00040404
.word 0x9a2c2c2c
.word 0x2c282c2c
.word 0x91b99530
.word 0x2c912c2c
.word 0x2c952c30
.word 0x91902c30
.word 0x30303095
.word 0x91303030
.word 0x913030ba
.word 0x2c302c28
.word 0x30953091
.word 0x302c3130
.word 0x30902c95
.word 0x952c2c2c
.word 0x912c3091
.word 0x302c302c
.word 0x2c303030
.word 0x30912c91
.word 0x902c2c2c
.word 0x2c2c9130
.word 0x2c313030
.word 0x952c282c
.word 0x91302c2c
.word 0x2c2c2c95
.word 0x30913030
.word 0x2c2c302c
.word 0x2c312c91
.word 0x282d3030
.word 0x31918c95
.word 0x2c2c2c2c
.word 0x302c302c
.word 0x2c283028
.word 0x2c2c2c30
.word 0x902c2c28
.word 0x2c000000
.word 0x2c28302c
.word 0x28282c2c
.word 0x2d2c2c28
.word 0x08040428
.word 0x08080408
.word 0x91302c2c
.word 0x2c30302c
.word 0x302c2c91
.word 0x2c31302c
.word 0x2c313095
.word 0x91902c95
.word 0x30302c91
.word 0x30912c2c
.word 0x2c302c28
.word 0x2c2c9195
.word 0x28282c30
.word 0x2d2d082c
.word 0x2d280404
.word 0x2c2c2c04
.word 0x2c282c2c
.word 0x2c2c2c28
.word 0x91910828
.word 0x2c082c2c
.word 0x2c312c2c
.word 0x91912c2c
.word 0x2c912c2c
.word 0x8c952c2c
.word 0x2c2c2c2c
.word 0x91902c91
.word 0x2c2c2c30
.word 0x08082c2c
.word 0x282d2c30
.word 0x082d2d08
.word 0x08080808
.word 0x91040828
.word 0x282c2c95
.word 0x9130312c
.word 0x2c2c9090
.word 0x2c282c91
.word 0x30000000
.word 0x2c28282c
.word 0x28282c2c
.word 0x2c282c08
.word 0x04040408
.word 0x04082808
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
.word 0x00000000
